[S] Change in osmo-ci[master]: obs-mirror: keep nightly builds for two years

2023-11-14 Thread fixeria
Attention is currently required from: laforge.

fixeria has posted comments on this change. ( 
https://gerrit.osmocom.org/c/osmo-ci/+/35014?usp=email )

Change subject: obs-mirror: keep nightly builds for two years
..


Patch Set 1: Code-Review+1


--
To view, visit https://gerrit.osmocom.org/c/osmo-ci/+/35014?usp=email
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: osmo-ci
Gerrit-Branch: master
Gerrit-Change-Id: Ic8529ee5679f15c4e4940a5f095374605c2e5c79
Gerrit-Change-Number: 35014
Gerrit-PatchSet: 1
Gerrit-Owner: laforge 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: fixeria 
Gerrit-Attention: laforge 
Gerrit-Comment-Date: Wed, 15 Nov 2023 07:08:41 +
Gerrit-HasComments: No
Gerrit-Has-Labels: Yes
Gerrit-MessageType: comment


[S] Change in docker-playground[master]: Use 2023q1 osmo-ttcn3-hacks branch for 2023q1 SUTs

2023-11-14 Thread fixeria
Attention is currently required from: daniel, dexter, neels, osmith.

fixeria has posted comments on this change. ( 
https://gerrit.osmocom.org/c/docker-playground/+/35013?usp=email )

Change subject: Use 2023q1 osmo-ttcn3-hacks branch for 2023q1 SUTs
..


Patch Set 2: Code-Review+1


--
To view, visit https://gerrit.osmocom.org/c/docker-playground/+/35013?usp=email
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: docker-playground
Gerrit-Branch: master
Gerrit-Change-Id: Id82425aca4a8ff87feb8a130d31712bc62fa27ed
Gerrit-Change-Number: 35013
Gerrit-PatchSet: 2
Gerrit-Owner: osmith 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: daniel 
Gerrit-Reviewer: dexter 
Gerrit-Reviewer: fixeria 
Gerrit-Reviewer: neels 
Gerrit-Attention: osmith 
Gerrit-Attention: neels 
Gerrit-Attention: daniel 
Gerrit-Attention: dexter 
Gerrit-Comment-Date: Wed, 15 Nov 2023 07:07:48 +
Gerrit-HasComments: No
Gerrit-Has-Labels: Yes
Gerrit-MessageType: comment


[L] Change in osmo-bsc[master]: Introduce per-BTS timers, RLC timer commands

2023-11-14 Thread fixeria
Attention is currently required from: arehbein, neels, pespin.

fixeria has posted comments on this change. ( 
https://gerrit.osmocom.org/c/osmo-bsc/+/31878?usp=email )

Change subject: Introduce per-BTS timers, RLC timer commands
..


Patch Set 12: Code-Review-1

(10 comments)

File include/osmocom/bsc/bts.h:

https://gerrit.osmocom.org/c/osmo-bsc/+/31878/comment/2d7bae3a_8d5e8eaf
PS12, Line 323: GSM_BTS_TDEF_ID_COUNTDOWN_VALUE
These are not standard 3GPP specified timer numbers, so they should not be 
positive. The usual practice in Osmocom is to use negative numbers for custom 
timer numbers, so that they show up as X1234 instead of T1234.


File src/osmo-bsc/bsc_vty.c:

https://gerrit.osmocom.org/c/osmo-bsc/+/31878/comment/5afd0fe2_569b3318
PS12, Line 353: bts_write_group_timers
So once we have found the matching group, don't we want to `break` the loop?


File src/osmo-bsc/bts_init.c:

https://gerrit.osmocom.org/c/osmo-bsc/+/31878/comment/f0e57fd2_65445e6e
PS12, Line 41: _templates
I am wondering why `_templates`? `_def` or `_defaults` maybe?


https://gerrit.osmocom.org/c/osmo-bsc/+/31878/comment/9ed2643f_a959f2a3
PS12, Line 56: Extended uplink TBF
This does not really explain what this timer is for. Same for DL below.


https://gerrit.osmocom.org/c/osmo-bsc/+/31878/comment/7c26fbb8_009132ce
PS12, Line 60: 3101
I actually find this problematic.

* 3GPP TS 44.018 defines T3101 in section 11.1.2 "Timers on the network side";
* 3GPP TS 44.060 defines N3101 in section 13.4 "Counters on the Network side".

The timer and counter are not the same thing. In this patch you're making a 
counter value N3101 configurable via `timer` related VTY commands. I find this 
extremely confusing, especially given that `T3101` in the VTY would actually 
reference a counter!

Same applies to N3103 and N3105. I don't know what would be a good way to solve 
this though. Maybe @nhofm...@sysmocom.de could suggest something, since he 
worked with timers a lot and AFAIR he wrote the tdef API.


File src/osmo-bsc/bts_ipaccess_nanobts_omlattr.c:

https://gerrit.osmocom.org/c/osmo-bsc/+/31878/comment/3e561314_e2bea10b
PS12, Line 253: struct abis_nm_ipacc_att_rlc_cfg
cosmetic: it's not necessary to specify the struct type here.


File src/osmo-bsc/bts_vty.c:

https://gerrit.osmocom.org/c/osmo-bsc/+/31878/comment/7333c7aa_29321e2f
PS3, Line 1896: static int parse_timer_arg_fmt(struct vty *vty, const char 
*timer_str, int *tid)
> Just as a general comment on why a lot of code has been replicated from 
> libosmocore with slight alte […]
I understand your motivation, this is indeed a problem. But maybe we should 
invest time into solving the fundamental problem in libosmocore, rather than 
replicating various stuff from there? Maybe also something 
@nhofm...@sysmocom.de can comment on.


File src/osmo-bsc/bts_vty.c:

https://gerrit.osmocom.org/c/osmo-bsc/+/31878/comment/c54dc09a_d87c74e9
PS12, Line 39: osmocom/bsc/bts.h
this header is already included below...


https://gerrit.osmocom.org/c/osmo-bsc/+/31878/comment/76c3bb2c_351f2192 
PS12, Line 56: limits.h
why including thise header? I cannot see `_MIN` or `_MAX` in new code...


File tests/nanobts_omlattr/nanobts_omlattr_test.c:

https://gerrit.osmocom.org/c/osmo-bsc/+/31878/comment/b1b4b444_65dd4b6e
PS12, Line 138: 3142
Why do these new timers need to be in `gsm_network_T_defs[]`?
They are per-BTS timers, while this is a global array for the whole network.



--
To view, visit https://gerrit.osmocom.org/c/osmo-bsc/+/31878?usp=email
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: osmo-bsc
Gerrit-Branch: master
Gerrit-Change-Id: I2c24110d8c977d6cc74c3c8e77bcc709ad9d2675
Gerrit-Change-Number: 31878
Gerrit-PatchSet: 12
Gerrit-Owner: arehbein 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: fixeria 
Gerrit-Reviewer: laforge 
Gerrit-Reviewer: neels 
Gerrit-Reviewer: pespin 
Gerrit-Attention: neels 
Gerrit-Attention: arehbein 
Gerrit-Attention: pespin 
Gerrit-Comment-Date: Wed, 15 Nov 2023 07:05:20 +
Gerrit-HasComments: Yes
Gerrit-Has-Labels: Yes
Comment-In-Reply-To: arehbein 
Comment-In-Reply-To: pespin 
Gerrit-MessageType: comment


[S] Change in osmo-ttcn3-hacks[master]: hnbgw: run TC_second_rab_assignment on nightly

2023-11-14 Thread osmith
osmith has posted comments on this change. ( 
https://gerrit.osmocom.org/c/osmo-ttcn3-hacks/+/35012?usp=email )

Change subject: hnbgw: run TC_second_rab_assignment on nightly
..


Patch Set 3:

(1 comment)

Commit Message:

https://gerrit.osmocom.org/c/osmo-ttcn3-hacks/+/35012/comment/5ada2fe9_ef7289d5
PS2, Line 7: hnbgw: run TC_second_rab_assignment on nightly
> ("only on nightly")
I had considered that, but it makes the subject > 50 characters



--
To view, visit https://gerrit.osmocom.org/c/osmo-ttcn3-hacks/+/35012?usp=email
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: osmo-ttcn3-hacks
Gerrit-Branch: master
Gerrit-Change-Id: Id09b1a22dbd391c19ecfe34af990ec1ef3bb5089
Gerrit-Change-Number: 35012
Gerrit-PatchSet: 3
Gerrit-Owner: osmith 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: daniel 
Gerrit-Reviewer: fixeria 
Gerrit-Reviewer: neels 
Gerrit-Reviewer: osmith 
Gerrit-Comment-Date: Wed, 15 Nov 2023 06:20:15 +
Gerrit-HasComments: Yes
Gerrit-Has-Labels: No
Comment-In-Reply-To: neels 
Gerrit-MessageType: comment


[S] Change in osmo-ttcn3-hacks[master]: hnbgw: run TC_second_rab_assignment on nightly

2023-11-14 Thread osmith
osmith has submitted this change. ( 
https://gerrit.osmocom.org/c/osmo-ttcn3-hacks/+/35012?usp=email )

Change subject: hnbgw: run TC_second_rab_assignment on nightly
..

hnbgw: run TC_second_rab_assignment on nightly

Fixes: OS#6253
Change-Id: Id09b1a22dbd391c19ecfe34af990ec1ef3bb5089
---
M hnbgw/HNBGW_Tests.ttcn
1 file changed, 14 insertions(+), 1 deletion(-)

Approvals:
  Jenkins Builder: Verified
  neels: Looks good to me, approved
  fixeria: Looks good to me, but someone else must approve




diff --git a/hnbgw/HNBGW_Tests.ttcn b/hnbgw/HNBGW_Tests.ttcn
index adb32bd..5bcd40c 100644
--- a/hnbgw/HNBGW_Tests.ttcn
+++ b/hnbgw/HNBGW_Tests.ttcn
@@ -2710,7 +2710,10 @@
execute( TC_sgsnpool_sccp_n_pcstate_detaches_cnlink() );
execute( TC_sgsnpool_sccp_n_pcstate_attaches_cnlink() );

-   execute(TC_second_rab_assignment());
+   /* Run only on nightly since it makes osmo-hnbgw <= 1.5.0 crash: 
OS#6253 */
+   if (f_osmo_repo_is("nightly")) {
+   execute(TC_second_rab_assignment());
+   }

/* Run at the end since it makes osmo-hnbgw <= 1.3.0 crash: OS#5676 */
execute(TC_hnb_reregister_reuse_sctp_assoc());

--
To view, visit https://gerrit.osmocom.org/c/osmo-ttcn3-hacks/+/35012?usp=email
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: osmo-ttcn3-hacks
Gerrit-Branch: master
Gerrit-Change-Id: Id09b1a22dbd391c19ecfe34af990ec1ef3bb5089
Gerrit-Change-Number: 35012
Gerrit-PatchSet: 3
Gerrit-Owner: osmith 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: daniel 
Gerrit-Reviewer: fixeria 
Gerrit-Reviewer: neels 
Gerrit-Reviewer: osmith 
Gerrit-MessageType: merged


[M] Change in osmocom-bb[master]: trxcon/l1sched: tx_tch[fh]_fn(): fix sending idle CSD frames

2023-11-14 Thread laforge
laforge has submitted this change. ( 
https://gerrit.osmocom.org/c/osmocom-bb/+/34993?usp=email )

Change subject: trxcon/l1sched: tx_tch[fh]_fn(): fix sending idle CSD frames
..

trxcon/l1sched: tx_tch[fh]_fn(): fix sending idle CSD frames

In accordance with 3GPP TS 44.021, sections 8.1.6 and 10.2.3, the
transmission of idle frames to the DTE is mandated when no data is
received from the radio interface.  An idle frame has all data,
status, and E-bits to binary '1' (excluding the alignment pattern).

This requirement is currently implemented by osmo-bts for the Uplink,
and is going to be adopted for the Downlink (see the related patch).

This patch brings trxcon/l1sched in sync with osmo-bts-trx.

Change-Id: I7dea3dde46bc02814e99c3e873298cc7ed045a51
Related: osmo-bts.git I0b25cfac41b6d8dcf3bfd9d46d51a9665f1b047a
Related: OS#1572, OS#4396
---
M src/host/trxcon/src/sched_lchan_tchf.c
M src/host/trxcon/src/sched_lchan_tchh.c
2 files changed, 53 insertions(+), 9 deletions(-)

Approvals:
  laforge: Looks good to me, approved
  Jenkins Builder: Verified
  osmith: Looks good to me, but someone else must approve




diff --git a/src/host/trxcon/src/sched_lchan_tchf.c 
b/src/host/trxcon/src/sched_lchan_tchf.c
index ac9ee6b..37e0cea 100644
--- a/src/host/trxcon/src/sched_lchan_tchf.c
+++ b/src/host/trxcon/src/sched_lchan_tchf.c
@@ -335,7 +335,11 @@
gsm0503_tch_fr144_encode(BUFPOS(bursts_p, 0), 
msgb_l2(msg));
/* Confirm data sending (pass ownership of the 
msgb/prim) */
l1sched_lchan_emit_data_cnf(lchan, msg, br->fn);
-   } /* else: all bits of this frame are set to zero */
+   } else {
+   ubit_t idle[290];
+   memset([0], 0x01, sizeof(idle));
+   gsm0503_tch_fr144_encode(BUFPOS(bursts_p, 0), [0]);
+   }
if ((msg = msg_facch) != NULL) {
gsm0503_tch_fr_facch_encode(BUFPOS(bursts_p, 0), 
msgb_l2(msg));
/* Confirm FACCH sending (pass ownership of the 
msgb/prim) */
@@ -349,7 +353,11 @@
gsm0503_tch_fr96_encode(BUFPOS(bursts_p, 0), 
msgb_l2(msg));
/* Confirm data sending (pass ownership of the 
msgb/prim) */
l1sched_lchan_emit_data_cnf(lchan, msg, br->fn);
-   } /* else: all bits of this frame are set to zero */
+   } else {
+   ubit_t idle[4 * 60];
+   memset([0], 0x01, sizeof(idle));
+   gsm0503_tch_fr96_encode(BUFPOS(bursts_p, 0), [0]);
+   }
if ((msg = msg_facch) != NULL) {
gsm0503_tch_fr_facch_encode(BUFPOS(bursts_p, 0), 
msgb_l2(msg));
/* Confirm FACCH sending (pass ownership of the 
msgb/prim) */
@@ -363,7 +371,11 @@
gsm0503_tch_fr48_encode(BUFPOS(bursts_p, 0), 
msgb_l2(msg));
/* Confirm data sending (pass ownership of the 
msgb/prim) */
l1sched_lchan_emit_data_cnf(lchan, msg, br->fn);
-   } /* else: all bits of this frame are set to zero */
+   } else {
+   ubit_t idle[2 * 60];
+   memset([0], 0x01, sizeof(idle));
+   gsm0503_tch_fr48_encode(BUFPOS(bursts_p, 0), [0]);
+   }
if ((msg = msg_facch) != NULL) {
gsm0503_tch_fr_facch_encode(BUFPOS(bursts_p, 0), 
msgb_l2(msg));
/* Confirm FACCH sending (pass ownership of the 
msgb/prim) */
@@ -372,14 +384,17 @@
goto send_burst;
/* CSD (TCH/F2.4): 3.6 kbit/s radio interface rate */
case GSM48_CMODE_DATA_3k6:
-   if (msg == NULL)
-   goto send_burst;
-   if (msg == msg_facch) {
+   if ((msg = msg_facch) != NULL) {
/* FACCH/F does steal a TCH/F2.4 frame completely */
rc = gsm0503_tch_fr_facch_encode(BUFPOS(bursts_p, 0), 
msgb_l2(msg));
-   } else {
+   } else if ((msg = msg_tch) != NULL) {
OSMO_ASSERT(msgb_l2len(msg) == 2 * 36);
rc = gsm0503_tch_fr24_encode(BUFPOS(bursts_p, 0), 
msgb_l2(msg));
+   } else {
+   ubit_t idle[2 * 36];
+   memset([0], 0x01, sizeof(idle));
+   gsm0503_tch_fr24_encode(BUFPOS(bursts_p, 0), [0]);
+   goto send_burst;
}
break;
default:
diff --git a/src/host/trxcon/src/sched_lchan_tchh.c 
b/src/host/trxcon/src/sched_lchan_tchh.c
index 0932cce..99e2680 100644
--- a/src/host/trxcon/src/sched_lchan_tchh.c
+++ b/src/host/trxcon/src/sched_lchan_tchh.c
@@ -542,7 +542,11 

[M] Change in osmocom-bb[master]: trxcon/l1sched: tx_tch[fh]_fn(): fix sending idle CSD frames

2023-11-14 Thread laforge
Attention is currently required from: fixeria.

laforge has posted comments on this change. ( 
https://gerrit.osmocom.org/c/osmocom-bb/+/34993?usp=email )

Change subject: trxcon/l1sched: tx_tch[fh]_fn(): fix sending idle CSD frames
..


Patch Set 3: Code-Review+2


--
To view, visit https://gerrit.osmocom.org/c/osmocom-bb/+/34993?usp=email
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: osmocom-bb
Gerrit-Branch: master
Gerrit-Change-Id: I7dea3dde46bc02814e99c3e873298cc7ed045a51
Gerrit-Change-Number: 34993
Gerrit-PatchSet: 3
Gerrit-Owner: fixeria 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: laforge 
Gerrit-Reviewer: osmith 
Gerrit-Attention: fixeria 
Gerrit-Comment-Date: Tue, 14 Nov 2023 20:44:35 +
Gerrit-HasComments: No
Gerrit-Has-Labels: Yes
Gerrit-MessageType: comment


[S] Change in libosmocore[master]: gsup: add message type for osmo-epdg CEAI interface

2023-11-14 Thread laforge
Attention is currently required from: lynxis lazus, pespin.

laforge has posted comments on this change. ( 
https://gerrit.osmocom.org/c/libosmocore/+/32033?usp=email )

Change subject: gsup: add message type for osmo-epdg CEAI interface
..


Patch Set 2: Code-Review+1


--
To view, visit https://gerrit.osmocom.org/c/libosmocore/+/32033?usp=email
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: libosmocore
Gerrit-Branch: master
Gerrit-Change-Id: I6f7c20340c99f94b1326a8a7dc99c86cf6a0dbc3
Gerrit-Change-Number: 32033
Gerrit-PatchSet: 2
Gerrit-Owner: lynxis lazus 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: laforge 
Gerrit-CC: pespin 
Gerrit-Attention: pespin 
Gerrit-Attention: lynxis lazus 
Gerrit-Comment-Date: Tue, 14 Nov 2023 20:44:00 +
Gerrit-HasComments: No
Gerrit-Has-Labels: Yes
Gerrit-MessageType: comment


[L] Change in osmo-bsc[master]: Introduce per-BTS timers, RLC timer commands

2023-11-14 Thread laforge
Attention is currently required from: arehbein, pespin.

laforge has posted comments on this change. ( 
https://gerrit.osmocom.org/c/osmo-bsc/+/31878?usp=email )

Change subject: Introduce per-BTS timers, RLC timer commands
..


Patch Set 12: Code-Review+1


--
To view, visit https://gerrit.osmocom.org/c/osmo-bsc/+/31878?usp=email
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: osmo-bsc
Gerrit-Branch: master
Gerrit-Change-Id: I2c24110d8c977d6cc74c3c8e77bcc709ad9d2675
Gerrit-Change-Number: 31878
Gerrit-PatchSet: 12
Gerrit-Owner: arehbein 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: laforge 
Gerrit-Reviewer: pespin 
Gerrit-Attention: arehbein 
Gerrit-Attention: pespin 
Gerrit-Comment-Date: Tue, 14 Nov 2023 20:41:33 +
Gerrit-HasComments: No
Gerrit-Has-Labels: Yes
Gerrit-MessageType: comment


[S] Change in docker-playground[master]: ttcn3-dia2gsup-test/osmo_dia2gsup: set connect timer to 200 ms

2023-11-14 Thread laforge
laforge has submitted this change. ( 
https://gerrit.osmocom.org/c/docker-playground/+/35000?usp=email )

Change subject: ttcn3-dia2gsup-test/osmo_dia2gsup: set connect timer to 200 ms
..

ttcn3-dia2gsup-test/osmo_dia2gsup: set connect timer to 200 ms

Related: OS#5657
Change-Id: I22839cdf76120bb6152b32059822001cbd7979d8
---
M ttcn3-dia2gsup-test/osmo_dia2gsup.config
1 file changed, 11 insertions(+), 0 deletions(-)

Approvals:
  Jenkins Builder: Verified
  laforge: Looks good to me, approved




diff --git a/ttcn3-dia2gsup-test/osmo_dia2gsup.config 
b/ttcn3-dia2gsup-test/osmo_dia2gsup.config
index dc0b876..4403935 100644
--- a/ttcn3-dia2gsup-test/osmo_dia2gsup.config
+++ b/ttcn3-dia2gsup-test/osmo_dia2gsup.config
@@ -5,6 +5,7 @@
 {diameter_ip, "172.18.10.20"},
 {diameter_port, 3868},
 {diameter_proto, sctp},
+{diameter_connect_timer, 200},

 {origin_host, "hss.localdomain"},
 {origin_realm, "localdomain"},

--
To view, visit https://gerrit.osmocom.org/c/docker-playground/+/35000?usp=email
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: docker-playground
Gerrit-Branch: master
Gerrit-Change-Id: I22839cdf76120bb6152b32059822001cbd7979d8
Gerrit-Change-Number: 35000
Gerrit-PatchSet: 1
Gerrit-Owner: lynxis lazus 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: laforge 
Gerrit-MessageType: merged


[S] Change in docker-playground[master]: ttcn3-dia2gsup-test/osmo_dia2gsup: set connect timer to 200 ms

2023-11-14 Thread laforge
Attention is currently required from: lynxis lazus.

laforge has posted comments on this change. ( 
https://gerrit.osmocom.org/c/docker-playground/+/35000?usp=email )

Change subject: ttcn3-dia2gsup-test/osmo_dia2gsup: set connect timer to 200 ms
..


Patch Set 1: Code-Review+2


--
To view, visit https://gerrit.osmocom.org/c/docker-playground/+/35000?usp=email
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: docker-playground
Gerrit-Branch: master
Gerrit-Change-Id: I22839cdf76120bb6152b32059822001cbd7979d8
Gerrit-Change-Number: 35000
Gerrit-PatchSet: 1
Gerrit-Owner: lynxis lazus 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: laforge 
Gerrit-Attention: lynxis lazus 
Gerrit-Comment-Date: Tue, 14 Nov 2023 20:37:10 +
Gerrit-HasComments: No
Gerrit-Has-Labels: Yes
Gerrit-MessageType: comment


[S] Change in osmo-ttcn3-hacks[master]: dia2gsup: sleep(1) to forget diameter state

2023-11-14 Thread laforge
laforge has submitted this change. ( 
https://gerrit.osmocom.org/c/osmo-ttcn3-hacks/+/34999?usp=email )

Change subject: dia2gsup: sleep(1) to forget diameter state
..

dia2gsup: sleep(1) to forget diameter state

Sleep to allow the remote to forget the connection (see diameter connect timer).

Related: OS#5657
Change-Id: Ib909eff5c381c6271b9d16e383bed3e78ca454da
---
M dia2gsup/DIA2GSUP_Tests.ttcn
1 file changed, 14 insertions(+), 0 deletions(-)

Approvals:
  laforge: Looks good to me, approved
  Jenkins Builder: Verified




diff --git a/dia2gsup/DIA2GSUP_Tests.ttcn b/dia2gsup/DIA2GSUP_Tests.ttcn
index 673038c..e12f17b 100644
--- a/dia2gsup/DIA2GSUP_Tests.ttcn
+++ b/dia2gsup/DIA2GSUP_Tests.ttcn
@@ -159,6 +159,8 @@
g_Tguard.start(t_guard);
activate(as_Tguard());

+   /* Sleep to allow the remote to forget the connection (see diameter 
connect timer). */
+   f_sleep(1.0);
f_init_gsup(testcasename());
f_init_diameter(testcasename());
 }

--
To view, visit https://gerrit.osmocom.org/c/osmo-ttcn3-hacks/+/34999?usp=email
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: osmo-ttcn3-hacks
Gerrit-Branch: master
Gerrit-Change-Id: Ib909eff5c381c6271b9d16e383bed3e78ca454da
Gerrit-Change-Number: 34999
Gerrit-PatchSet: 2
Gerrit-Owner: lynxis lazus 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: laforge 
Gerrit-MessageType: merged


[S] Change in osmo-ttcn3-hacks[master]: dia2gsup: sleep(1) to forget diameter state

2023-11-14 Thread laforge
Attention is currently required from: lynxis lazus.

laforge has posted comments on this change. ( 
https://gerrit.osmocom.org/c/osmo-ttcn3-hacks/+/34999?usp=email )

Change subject: dia2gsup: sleep(1) to forget diameter state
..


Patch Set 2: Code-Review+2


--
To view, visit https://gerrit.osmocom.org/c/osmo-ttcn3-hacks/+/34999?usp=email
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: osmo-ttcn3-hacks
Gerrit-Branch: master
Gerrit-Change-Id: Ib909eff5c381c6271b9d16e383bed3e78ca454da
Gerrit-Change-Number: 34999
Gerrit-PatchSet: 2
Gerrit-Owner: lynxis lazus 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: laforge 
Gerrit-Attention: lynxis lazus 
Gerrit-Comment-Date: Tue, 14 Nov 2023 20:35:53 +
Gerrit-HasComments: No
Gerrit-Has-Labels: Yes
Gerrit-MessageType: comment


[S] Change in osmo-ci[master]: obs-mirror: keep nightly builds for two years

2023-11-14 Thread laforge
laforge has uploaded this change for review. ( 
https://gerrit.osmocom.org/c/osmo-ci/+/35014?usp=email )


Change subject: obs-mirror: keep nightly builds for two years
..

obs-mirror: keep nightly builds for two years

As we're moving the archive to a machine with sufficient storage,
let's extend the time we keep an archive of nightly builds from
one month to two years.

Change-Id: Ic8529ee5679f15c4e4940a5f095374605c2e5c79
Related: OS#6257
---
M contrib/obs-mirror/rm-old-nightly-archives.sh
1 file changed, 15 insertions(+), 1 deletion(-)



  git pull ssh://gerrit.osmocom.org:29418/osmo-ci refs/changes/14/35014/1

diff --git a/contrib/obs-mirror/rm-old-nightly-archives.sh 
b/contrib/obs-mirror/rm-old-nightly-archives.sh
index 485bf01..485788f 100755
--- a/contrib/obs-mirror/rm-old-nightly-archives.sh
+++ b/contrib/obs-mirror/rm-old-nightly-archives.sh
@@ -6,7 +6,7 @@
 DRY=0

 # Get removal date in seconds since epoch and display it
-DATE_RM_SEC=$(expr $(date +%s) - 3600 \* 24 \* 32)
+DATE_RM_SEC=$(expr $(date +%s) - 3600 \* 24 \* 365 \* 2)
 DATE_RM_STR=$(date -d "@$DATE_RM_SEC" +"%Y-%m-%d")
 echo "Removing nightly archives from $DATE_RM_STR and older (DRY=$DRY)"


--
To view, visit https://gerrit.osmocom.org/c/osmo-ci/+/35014?usp=email
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: osmo-ci
Gerrit-Branch: master
Gerrit-Change-Id: Ic8529ee5679f15c4e4940a5f095374605c2e5c79
Gerrit-Change-Number: 35014
Gerrit-PatchSet: 1
Gerrit-Owner: laforge 
Gerrit-MessageType: newchange


[S] Change in osmo-ttcn3-hacks[master]: hnbgw: run TC_second_rab_assignment on nightly

2023-11-14 Thread neels
Attention is currently required from: daniel, osmith.

neels has posted comments on this change. ( 
https://gerrit.osmocom.org/c/osmo-ttcn3-hacks/+/35012?usp=email )

Change subject: hnbgw: run TC_second_rab_assignment on nightly
..


Patch Set 2: Code-Review+2

(1 comment)

Commit Message:

https://gerrit.osmocom.org/c/osmo-ttcn3-hacks/+/35012/comment/3846df74_620c0b8d
PS2, Line 7: hnbgw: run TC_second_rab_assignment on nightly
("only on nightly")



--
To view, visit https://gerrit.osmocom.org/c/osmo-ttcn3-hacks/+/35012?usp=email
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: osmo-ttcn3-hacks
Gerrit-Branch: master
Gerrit-Change-Id: Id09b1a22dbd391c19ecfe34af990ec1ef3bb5089
Gerrit-Change-Number: 35012
Gerrit-PatchSet: 2
Gerrit-Owner: osmith 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: daniel 
Gerrit-Reviewer: fixeria 
Gerrit-Reviewer: neels 
Gerrit-Attention: osmith 
Gerrit-Attention: daniel 
Gerrit-Comment-Date: Tue, 14 Nov 2023 16:19:07 +
Gerrit-HasComments: Yes
Gerrit-Has-Labels: Yes
Gerrit-MessageType: comment


[S] Change in docker-playground[master]: Use 2023q1 osmo-ttcn3-hacks branch for 2023q1 SUTs

2023-11-14 Thread osmith
Attention is currently required from: daniel, dexter, fixeria, osmith.

Hello Jenkins Builder, daniel, dexter, fixeria,

I'd like you to reexamine a change. Please visit

https://gerrit.osmocom.org/c/docker-playground/+/35013?usp=email

to look at the new patch set (#2).

The following approvals got outdated and were removed:
Code-Review+1 by fixeria, Verified+1 by Jenkins Builder


Change subject: Use 2023q1 osmo-ttcn3-hacks branch for 2023q1 SUTs
..

Use 2023q1 osmo-ttcn3-hacks branch for 2023q1 SUTs

Fix the TTCN3-centos-pcu-test-2023q1 jenkins job where currently most
tests are failing. This is because 2023q1 is using an older PCUIF
version that is no longer supported by osmo-ttcn3-hacks.git. As
discussed, use a 2023q1 branch of osmo-ttcn3-hacks where the support was
not removed yet.

Fixes: SYS#6638
Change-Id: Id82425aca4a8ff87feb8a130d31712bc62fa27ed
---
M jenkins-common.sh
1 file changed, 38 insertions(+), 0 deletions(-)


  git pull ssh://gerrit.osmocom.org:29418/docker-playground 
refs/changes/13/35013/2
--
To view, visit https://gerrit.osmocom.org/c/docker-playground/+/35013?usp=email
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: docker-playground
Gerrit-Branch: master
Gerrit-Change-Id: Id82425aca4a8ff87feb8a130d31712bc62fa27ed
Gerrit-Change-Number: 35013
Gerrit-PatchSet: 2
Gerrit-Owner: osmith 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: daniel 
Gerrit-Reviewer: dexter 
Gerrit-Reviewer: fixeria 
Gerrit-Attention: osmith 
Gerrit-Attention: fixeria 
Gerrit-Attention: daniel 
Gerrit-Attention: dexter 
Gerrit-MessageType: newpatchset


[M] Change in osmocom-bb[master]: trxcon/l1sched: tx_tch[fh]_fn(): fix sending idle CSD frames

2023-11-14 Thread osmith
Attention is currently required from: fixeria, laforge.

osmith has posted comments on this change. ( 
https://gerrit.osmocom.org/c/osmocom-bb/+/34993?usp=email )

Change subject: trxcon/l1sched: tx_tch[fh]_fn(): fix sending idle CSD frames
..


Patch Set 3: Code-Review+1


--
To view, visit https://gerrit.osmocom.org/c/osmocom-bb/+/34993?usp=email
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: osmocom-bb
Gerrit-Branch: master
Gerrit-Change-Id: I7dea3dde46bc02814e99c3e873298cc7ed045a51
Gerrit-Change-Number: 34993
Gerrit-PatchSet: 3
Gerrit-Owner: fixeria 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: laforge 
Gerrit-Reviewer: osmith 
Gerrit-Attention: laforge 
Gerrit-Attention: fixeria 
Gerrit-Comment-Date: Tue, 14 Nov 2023 14:02:57 +
Gerrit-HasComments: No
Gerrit-Has-Labels: Yes
Gerrit-MessageType: comment


[S] Change in osmo-bts[master]: osmo-bts-trx: eliminate ul_bursts_prev, use the primary buffer

2023-11-14 Thread fixeria
fixeria has submitted this change. ( 
https://gerrit.osmocom.org/c/osmo-bts/+/35011?usp=email )

Change subject: osmo-bts-trx: eliminate ul_bursts_prev, use the primary buffer
..

osmo-bts-trx: eliminate ul_bursts_prev, use the primary buffer

When adding support for Circuit Switched Data calls, we had to enlarge
the burst buffer size to accommodate bits for a maximum of 24 bursts.

Let's take advantage of this by utilizing the currently unused part of
the Uplink burst buffer for storing bits of previously decoded blocks.
This eliminates the need to allocate additional memory for SACCH.

Change-Id: I15047cd1df4476054b36f05616e41f5297d9bfe5
Related: SYS#5114, OS#4794, OS#4795, OS#4796
---
M include/osmo-bts/scheduler.h
M src/common/scheduler.c
M src/osmo-bts-trx/sched_lchan_xcch.c
3 files changed, 24 insertions(+), 14 deletions(-)

Approvals:
  osmith: Looks good to me, approved
  Jenkins Builder: Verified
  laforge: Looks good to me, but someone else must approve




diff --git a/include/osmo-bts/scheduler.h b/include/osmo-bts/scheduler.h
index b9c7350..aea5595 100644
--- a/include/osmo-bts/scheduler.h
+++ b/include/osmo-bts/scheduler.h
@@ -92,7 +92,6 @@
enum trx_mod_type   dl_mod_type;/* Downlink modulation type */
uint8_t dl_mask;/* mask of transmitted bursts */
sbit_t  *ul_bursts; /* burst buffer for RX */
-   sbit_t  *ul_bursts_prev;/* previous burst buffer for RX 
(repeated SACCH) */
uint32_tul_first_fn;/* fn of first burst */
uint32_tul_mask;/* mask of received bursts */

diff --git a/src/common/scheduler.c b/src/common/scheduler.c
index 0e62b65..ef03932 100644
--- a/src/common/scheduler.c
+++ b/src/common/scheduler.c
@@ -1084,11 +1084,8 @@
const size_t buf_size = 24 * GSM_NBITS_NB_GMSK_PAYLOAD;
if (trx_chan_desc[chan].dl_fn != NULL)
chan_state->dl_bursts = talloc_zero_size(l1ts, 
buf_size);
-   if (trx_chan_desc[chan].ul_fn != NULL) {
+   if (trx_chan_desc[chan].ul_fn != NULL)
chan_state->ul_bursts = talloc_zero_size(l1ts, 
buf_size);
-   if (L1SAP_IS_LINK_SACCH(trx_chan_desc[chan].link_id))
-   chan_state->ul_bursts_prev = 
talloc_zero_size(l1ts, buf_size);
-   }
} else {
chan_state->ho_rach_detect = 0;

@@ -1100,7 +1097,6 @@
/* Release memory used by Rx/Tx burst buffers */
TALLOC_FREE(chan_state->dl_bursts);
TALLOC_FREE(chan_state->ul_bursts);
-   TALLOC_FREE(chan_state->ul_bursts_prev);
}

chan_state->active = active;
diff --git a/src/osmo-bts-trx/sched_lchan_xcch.c 
b/src/osmo-bts-trx/sched_lchan_xcch.c
index a1a5e30..b6b5117 100644
--- a/src/osmo-bts-trx/sched_lchan_xcch.c
+++ b/src/osmo-bts-trx/sched_lchan_xcch.c
@@ -67,7 +67,9 @@

/* clear burst & store frame number of first burst */
if (bi->bid == 0) {
-   memset(bursts_p, 0, BPLEN * 4);
+   if (rep_sacch) /* Keep a copy to ease decoding in the next 
repetition pass */
+   memcpy(BUFPOS(bursts_p, 4), BUFPOS(bursts_p, 0), BPLEN 
* 4);
+   memset(BUFPOS(bursts_p, 0), 0, BPLEN * 4);
*mask = 0x0;
*first_fn = bi->fn;
}
@@ -107,7 +109,7 @@
*mask = 0x0;

/* decode */
-   rc = gsm0503_xcch_decode(l2, bursts_p, _errors, _bits_total);
+   rc = gsm0503_xcch_decode(l2, BUFPOS(bursts_p, 0), _errors, 
_bits_total);
if (rc) {
LOGL1SB(DL1P, LOGL_NOTICE, l1ts, bi,
BAD_DATA_MSG_FMT "\n", BAD_DATA_MSG_ARGS);
@@ -118,8 +120,8 @@
 * information from the previous SACCH block. See also:
 * 3GPP TS 44.006, section 11.2 */
if (rep_sacch) {
-   add_sbits(bursts_p, chan_state->ul_bursts_prev);
-   rc = gsm0503_xcch_decode(l2, bursts_p, _errors, 
_bits_total);
+   add_sbits(BUFPOS(bursts_p, 0), BUFPOS(bursts_p, 4));
+   rc = gsm0503_xcch_decode(l2, BUFPOS(bursts_p, 0), 
_errors, _bits_total);
if (rc) {
LOGL1SB(DL1P, LOGL_NOTICE, l1ts, bi,
   "Combining current SACCH block with 
previous SACCH block also yields bad data (%u/%u)\n",
@@ -136,10 +138,6 @@

ber10k = compute_ber10k(n_bits_total, n_errors);

-   /* Keep a copy to ease decoding in the next repetition pass */
-   if (rep_sacch)
-   memcpy(chan_state->ul_bursts_prev, bursts_p, BPLEN * 4);
-
return _sched_compose_ph_data_ind(l1ts, *first_fn, bi->chan,
  [0], 

[S] Change in osmo-bts[master]: osmo-bts-trx: eliminate ul_bursts_prev, use the primary buffer

2023-11-14 Thread osmith
Attention is currently required from: dexter, fixeria.

osmith has posted comments on this change. ( 
https://gerrit.osmocom.org/c/osmo-bts/+/35011?usp=email )

Change subject: osmo-bts-trx: eliminate ul_bursts_prev, use the primary buffer
..


Patch Set 2: Code-Review+2


--
To view, visit https://gerrit.osmocom.org/c/osmo-bts/+/35011?usp=email
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: osmo-bts
Gerrit-Branch: master
Gerrit-Change-Id: I15047cd1df4476054b36f05616e41f5297d9bfe5
Gerrit-Change-Number: 35011
Gerrit-PatchSet: 2
Gerrit-Owner: fixeria 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: dexter 
Gerrit-Reviewer: laforge 
Gerrit-Reviewer: osmith 
Gerrit-Attention: fixeria 
Gerrit-Attention: dexter 
Gerrit-Comment-Date: Tue, 14 Nov 2023 13:55:13 +
Gerrit-HasComments: No
Gerrit-Has-Labels: Yes
Gerrit-MessageType: comment


[S] Change in pysim[master]: ts_31_102: correct name of EF_ePDGId

2023-11-14 Thread fixeria
Attention is currently required from: iw0, laforge.

fixeria has posted comments on this change. ( 
https://gerrit.osmocom.org/c/pysim/+/35024?usp=email )

Change subject: ts_31_102: correct name of EF_ePDGId
..


Patch Set 2: Code-Review+1


--
To view, visit https://gerrit.osmocom.org/c/pysim/+/35024?usp=email
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: pysim
Gerrit-Branch: master
Gerrit-Change-Id: I2c27a7f325f75274e2110eb312b623cf9e7dab47
Gerrit-Change-Number: 35024
Gerrit-PatchSet: 2
Gerrit-Owner: iw0 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: fixeria 
Gerrit-Reviewer: laforge 
Gerrit-Attention: iw0 
Gerrit-Attention: laforge 
Gerrit-Comment-Date: Tue, 14 Nov 2023 13:34:07 +
Gerrit-HasComments: No
Gerrit-Has-Labels: Yes
Gerrit-MessageType: comment


[S] Change in docker-playground[master]: Use 2023q1 osmo-ttcn3-hacks branch for 2023q1 SUTs

2023-11-14 Thread fixeria
Attention is currently required from: daniel, dexter, osmith.

fixeria has posted comments on this change. ( 
https://gerrit.osmocom.org/c/docker-playground/+/35013?usp=email )

Change subject: Use 2023q1 osmo-ttcn3-hacks branch for 2023q1 SUTs
..


Patch Set 1: Code-Review+1


--
To view, visit https://gerrit.osmocom.org/c/docker-playground/+/35013?usp=email
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: docker-playground
Gerrit-Branch: master
Gerrit-Change-Id: Id82425aca4a8ff87feb8a130d31712bc62fa27ed
Gerrit-Change-Number: 35013
Gerrit-PatchSet: 1
Gerrit-Owner: osmith 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: daniel 
Gerrit-Reviewer: dexter 
Gerrit-Reviewer: fixeria 
Gerrit-Attention: osmith 
Gerrit-Attention: daniel 
Gerrit-Attention: dexter 
Gerrit-Comment-Date: Tue, 14 Nov 2023 13:32:01 +
Gerrit-HasComments: No
Gerrit-Has-Labels: Yes
Gerrit-MessageType: comment


[S] Change in pysim[master]: ts_31_102: correct name of EF_ePDGId

2023-11-14 Thread iw0
iw0 has uploaded a new patch set (#2). ( 
https://gerrit.osmocom.org/c/pysim/+/35024?usp=email )


Change subject: ts_31_102: correct name of EF_ePDGId
..

ts_31_102: correct name of EF_ePDGId

In 31.102 v17.10, file 6ff3 is called "EF_ePDGId". Adjust the spelling to match.

Change-Id: I2c27a7f325f75274e2110eb312b623cf9e7dab47
---
M pySim/ts_31_102.py
1 file changed, 12 insertions(+), 1 deletion(-)


  git pull ssh://gerrit.osmocom.org:29418/pysim refs/changes/24/35024/2
--
To view, visit https://gerrit.osmocom.org/c/pysim/+/35024?usp=email
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: pysim
Gerrit-Branch: master
Gerrit-Change-Id: I2c27a7f325f75274e2110eb312b623cf9e7dab47
Gerrit-Change-Number: 35024
Gerrit-PatchSet: 2
Gerrit-Owner: iw0 
Gerrit-CC: Jenkins Builder
Gerrit-MessageType: newpatchset


[S] Change in pysim[master]: ts_31_102: correct name of EF_ePDGId In 31.102 v17.10, file 6ff3 is c...

2023-11-14 Thread iw0
iw0 has uploaded this change for review. ( 
https://gerrit.osmocom.org/c/pysim/+/35024?usp=email )


Change subject: ts_31_102: correct name of EF_ePDGId In 31.102 v17.10, file 
6ff3 is called "EF_ePDGId". Adjust the spelling to match.
..

ts_31_102: correct name of EF_ePDGId
In 31.102 v17.10, file 6ff3 is called "EF_ePDGId". Adjust the spelling to match.

Change-Id: I2c27a7f325f75274e2110eb312b623cf9e7dab47
---
M pySim/ts_31_102.py
1 file changed, 11 insertions(+), 1 deletion(-)



  git pull ssh://gerrit.osmocom.org:29418/pysim refs/changes/24/35024/1

diff --git a/pySim/ts_31_102.py b/pySim/ts_31_102.py
index 738f107..0fcf883 100644
--- a/pySim/ts_31_102.py
+++ b/pySim/ts_31_102.py
@@ -880,7 +880,7 @@
'IPv4': 
HexAdapter(GreedyBytes),
'IPv6': 
HexAdapter(GreedyBytes)}))

-def __init__(self, fid='6ff3', sfid=None, name='EF.eDPDGId', desc='Home 
ePDG Identifier', **kwargs):
+def __init__(self, fid='6ff3', sfid=None, name='EF.ePDGId', desc='Home 
ePDG Identifier', **kwargs):
 super().__init__(fid, sfid=sfid, name=name, desc=desc, **kwargs)
 self._tlv = EF_ePDGId.ePDGId


--
To view, visit https://gerrit.osmocom.org/c/pysim/+/35024?usp=email
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: pysim
Gerrit-Branch: master
Gerrit-Change-Id: I2c27a7f325f75274e2110eb312b623cf9e7dab47
Gerrit-Change-Number: 35024
Gerrit-PatchSet: 1
Gerrit-Owner: iw0 
Gerrit-MessageType: newchange


[S] Change in docker-playground[master]: Use 2023q1 osmo-ttcn3-hacks branch for 2023q1 SUTs

2023-11-14 Thread osmith
osmith has uploaded this change for review. ( 
https://gerrit.osmocom.org/c/docker-playground/+/35013?usp=email )


Change subject: Use 2023q1 osmo-ttcn3-hacks branch for 2023q1 SUTs
..

Use 2023q1 osmo-ttcn3-hacks branch for 2023q1 SUTs

Fix the TTCN3-centos-pcu-test-2023q1 jenkins job where currently most
tests are failing. This is because 2023q1 is using an older PCUIF
version that is no longer supported by osmo-ttcn3-hacks.git. As
discussed, use a 2023q1 branch of osmo-ttcn3-hacks where the support was
not removed yet.

Fixes: SYS#6638
Change-Id: Id82425aca4a8ff87feb8a130d31712bc62fa27ed
---
M jenkins-common.sh
1 file changed, 39 insertions(+), 0 deletions(-)



  git pull ssh://gerrit.osmocom.org:29418/docker-playground 
refs/changes/13/35013/1

diff --git a/jenkins-common.sh b/jenkins-common.sh
index 4e476f6..65c4942 100644
--- a/jenkins-common.sh
+++ b/jenkins-common.sh
@@ -122,6 +122,28 @@
set -x
 }

+# Get the osmo-ttcn3-hacks branch to use, based on the IMAGE_SUFFIX we are
+# testing. This allows e.g. running 2023q1 SUTs against the 2023q1 branch of
+# osmo-ttcn3-hacks.git (SYS#6638). The OSMO_TTCN3_BRANCH env var can be used to
+# override it in any case.
+# $1: image name (e.g. ttcn3-pcu-test)
+# $IMAGE_SUFFIX: e.g. 2023q1-centos8
+docker_osmo_ttcn3_branch() {
+   if [ -n "$OSMO_TTCN3_BRANCH" ]; then
+   echo "$OSMO_TTCN3_BRANCH"
+   return
+   fi
+
+   case "$IMAGE_SUFFIX" in
+   20*q*)
+   echo "$IMAGE_SUFFIX" | cut -d- -f 1
+   ;;
+   *)
+   echo "master"
+   ;;
+   esac
+}
+
 # Make sure required images are available and build them if necessary.
 # $*: image names (e.g. "debian-bullseye-build", "osmo-mgw-master", 
"osmo-mgw-master-centos8")
 #  The images are automatically built from the Dockerfile of the subdir of
@@ -184,6 +206,7 @@
UPSTREAM_DISTRO="$upstream_distro_arg" \
DISTRO="$distro_arg" \
IMAGE="$REPO_USER/$i" \
+   OSMO_TTCN3_BRANCH="$(docker_osmo_ttcn3_branch)" 
\
|| exit 1
fi


--
To view, visit https://gerrit.osmocom.org/c/docker-playground/+/35013?usp=email
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: docker-playground
Gerrit-Branch: master
Gerrit-Change-Id: Id82425aca4a8ff87feb8a130d31712bc62fa27ed
Gerrit-Change-Number: 35013
Gerrit-PatchSet: 1
Gerrit-Owner: osmith 
Gerrit-MessageType: newchange


[S] Change in osmo-bts[master]: osmo-bts-trx: add_sbits(): simplify, improve coding style

2023-11-14 Thread fixeria
fixeria has submitted this change. ( 
https://gerrit.osmocom.org/c/osmo-bts/+/35009?usp=email )

Change subject: osmo-bts-trx: add_sbits(): simplify, improve coding style
..

osmo-bts-trx: add_sbits(): simplify, improve coding style

Change-Id: I518a8ea268a9a6d48b04c291a03e5efbed5f571d
---
M src/osmo-bts-trx/sched_lchan_xcch.c
1 file changed, 12 insertions(+), 7 deletions(-)

Approvals:
  daniel: Looks good to me, but someone else must approve
  Jenkins Builder: Verified
  laforge: Looks good to me, but someone else must approve
  fixeria: Looks good to me, approved




diff --git a/src/osmo-bts-trx/sched_lchan_xcch.c 
b/src/osmo-bts-trx/sched_lchan_xcch.c
index ccf685f..b36f4e8 100644
--- a/src/osmo-bts-trx/sched_lchan_xcch.c
+++ b/src/osmo-bts-trx/sched_lchan_xcch.c
@@ -36,14 +36,10 @@
 #include 

 /* Add two arrays of sbits */
-static void add_sbits(sbit_t * current, const sbit_t * previous)
+static void add_sbits(sbit_t *current, const sbit_t *previous)
 {
-   unsigned int i;
-   for (i = 0; i < 464; i++) {
-   *current = (*current) / 2 + (*previous) / 2;
-   current++;
-   previous++;
-   }
+   for (unsigned int i = 0; i < 464; i++)
+   current[i] = current[i] / 2 + previous[i] / 2;
 }

 /*! \brief a single (SDCCH/SACCH) burst was received by the PHY, process it */

--
To view, visit https://gerrit.osmocom.org/c/osmo-bts/+/35009?usp=email
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: osmo-bts
Gerrit-Branch: master
Gerrit-Change-Id: I518a8ea268a9a6d48b04c291a03e5efbed5f571d
Gerrit-Change-Number: 35009
Gerrit-PatchSet: 2
Gerrit-Owner: fixeria 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: daniel 
Gerrit-Reviewer: fixeria 
Gerrit-Reviewer: laforge 
Gerrit-MessageType: merged


[S] Change in osmo-bts[master]: osmo-bts-trx: use BPLEN macro instead of magic numbers

2023-11-14 Thread fixeria
fixeria has posted comments on this change. ( 
https://gerrit.osmocom.org/c/osmo-bts/+/35010?usp=email )

Change subject: osmo-bts-trx: use BPLEN macro instead of magic numbers
..


Patch Set 1: Code-Review+2


--
To view, visit https://gerrit.osmocom.org/c/osmo-bts/+/35010?usp=email
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: osmo-bts
Gerrit-Branch: master
Gerrit-Change-Id: I7d89b2e50c7eeb54b734c4959eeeb1c63a51a315
Gerrit-Change-Number: 35010
Gerrit-PatchSet: 1
Gerrit-Owner: fixeria 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: daniel 
Gerrit-Reviewer: fixeria 
Gerrit-Reviewer: laforge 
Gerrit-Comment-Date: Tue, 14 Nov 2023 12:22:18 +
Gerrit-HasComments: No
Gerrit-Has-Labels: Yes
Gerrit-MessageType: comment


[S] Change in osmo-bts[master]: osmo-bts-trx: use BPLEN macro instead of magic numbers

2023-11-14 Thread fixeria
fixeria has submitted this change. ( 
https://gerrit.osmocom.org/c/osmo-bts/+/35010?usp=email )

Change subject: osmo-bts-trx: use BPLEN macro instead of magic numbers
..

osmo-bts-trx: use BPLEN macro instead of magic numbers

Change-Id: I7d89b2e50c7eeb54b734c4959eeeb1c63a51a315
---
M src/osmo-bts-trx/sched_lchan_xcch.c
1 file changed, 12 insertions(+), 3 deletions(-)

Approvals:
  laforge: Looks good to me, but someone else must approve
  daniel: Looks good to me, but someone else must approve
  Jenkins Builder: Verified
  fixeria: Looks good to me, approved




diff --git a/src/osmo-bts-trx/sched_lchan_xcch.c 
b/src/osmo-bts-trx/sched_lchan_xcch.c
index b36f4e8..a1a5e30 100644
--- a/src/osmo-bts-trx/sched_lchan_xcch.c
+++ b/src/osmo-bts-trx/sched_lchan_xcch.c
@@ -38,7 +38,7 @@
 /* Add two arrays of sbits */
 static void add_sbits(sbit_t *current, const sbit_t *previous)
 {
-   for (unsigned int i = 0; i < 464; i++)
+   for (unsigned int i = 0; i < BPLEN * 4; i++)
current[i] = current[i] / 2 + previous[i] / 2;
 }

@@ -67,7 +67,7 @@

/* clear burst & store frame number of first burst */
if (bi->bid == 0) {
-   memset(bursts_p, 0, 464);
+   memset(bursts_p, 0, BPLEN * 4);
*mask = 0x0;
*first_fn = bi->fn;
}
@@ -138,7 +138,7 @@

/* Keep a copy to ease decoding in the next repetition pass */
if (rep_sacch)
-   memcpy(chan_state->ul_bursts_prev, bursts_p, 464);
+   memcpy(chan_state->ul_bursts_prev, bursts_p, BPLEN * 4);

return _sched_compose_ph_data_ind(l1ts, *first_fn, bi->chan,
  [0], l2_len,

--
To view, visit https://gerrit.osmocom.org/c/osmo-bts/+/35010?usp=email
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: osmo-bts
Gerrit-Branch: master
Gerrit-Change-Id: I7d89b2e50c7eeb54b734c4959eeeb1c63a51a315
Gerrit-Change-Number: 35010
Gerrit-PatchSet: 2
Gerrit-Owner: fixeria 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: daniel 
Gerrit-Reviewer: fixeria 
Gerrit-Reviewer: laforge 
Gerrit-MessageType: merged


[S] Change in osmo-bts[master]: osmo-bts-trx: add_sbits(): simplify, improve coding style

2023-11-14 Thread fixeria
fixeria has posted comments on this change. ( 
https://gerrit.osmocom.org/c/osmo-bts/+/35009?usp=email )

Change subject: osmo-bts-trx: add_sbits(): simplify, improve coding style
..


Patch Set 1: Code-Review+2


--
To view, visit https://gerrit.osmocom.org/c/osmo-bts/+/35009?usp=email
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: osmo-bts
Gerrit-Branch: master
Gerrit-Change-Id: I518a8ea268a9a6d48b04c291a03e5efbed5f571d
Gerrit-Change-Number: 35009
Gerrit-PatchSet: 1
Gerrit-Owner: fixeria 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: daniel 
Gerrit-Reviewer: fixeria 
Gerrit-Reviewer: laforge 
Gerrit-Comment-Date: Tue, 14 Nov 2023 12:22:15 +
Gerrit-HasComments: No
Gerrit-Has-Labels: Yes
Gerrit-MessageType: comment


[S] Change in osmo-ttcn3-hacks[master]: hnbgw: run TC_second_rab_assignment on nightly

2023-11-14 Thread fixeria
Attention is currently required from: osmith.

fixeria has posted comments on this change. ( 
https://gerrit.osmocom.org/c/osmo-ttcn3-hacks/+/35012?usp=email )

Change subject: hnbgw: run TC_second_rab_assignment on nightly
..


Patch Set 2: Code-Review+1


--
To view, visit https://gerrit.osmocom.org/c/osmo-ttcn3-hacks/+/35012?usp=email
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: osmo-ttcn3-hacks
Gerrit-Branch: master
Gerrit-Change-Id: Id09b1a22dbd391c19ecfe34af990ec1ef3bb5089
Gerrit-Change-Number: 35012
Gerrit-PatchSet: 2
Gerrit-Owner: osmith 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: fixeria 
Gerrit-Attention: osmith 
Gerrit-Comment-Date: Tue, 14 Nov 2023 12:21:36 +
Gerrit-HasComments: No
Gerrit-Has-Labels: Yes
Gerrit-MessageType: comment


[S] Change in osmo-bts[master]: osmo-bts-trx: tx_tch[fh]_fn(): use BUFPOS macro everywhere

2023-11-14 Thread fixeria
fixeria has submitted this change. ( 
https://gerrit.osmocom.org/c/osmo-bts/+/34990?usp=email )

Change subject: osmo-bts-trx: tx_tch[fh]_fn(): use BUFPOS macro everywhere
..

osmo-bts-trx: tx_tch[fh]_fn(): use BUFPOS macro everywhere

For the sake of consistency.

Change-Id: I16ce4c979c5b44fd67324eb2ed3da28a4b78221b
Related: OS#1572
---
M src/osmo-bts-trx/sched_lchan_tchf.c
M src/osmo-bts-trx/sched_lchan_tchh.c
2 files changed, 15 insertions(+), 3 deletions(-)

Approvals:
  Jenkins Builder: Verified
  falconia: Looks good to me, but someone else must approve
  laforge: Looks good to me, but someone else must approve
  fixeria: Looks good to me, approved




diff --git a/src/osmo-bts-trx/sched_lchan_tchf.c 
b/src/osmo-bts-trx/sched_lchan_tchf.c
index ae800a9..34af8a1 100644
--- a/src/osmo-bts-trx/sched_lchan_tchf.c
+++ b/src/osmo-bts-trx/sched_lchan_tchf.c
@@ -539,12 +539,12 @@
switch (tch_mode) {
case GSM48_CMODE_SPEECH_V1:
case GSM48_CMODE_SPEECH_EFR:
-   rc = gsm0503_tch_fr_encode(bursts_p, NULL, 0, 1);
+   rc = gsm0503_tch_fr_encode(BUFPOS(bursts_p, 0), NULL, 
0, 1);
if (rc == 0)
break;
/* fall-through */
default:
-   gsm0503_tch_fr_encode(bursts_p, dummy, sizeof(dummy), 
1);
+   gsm0503_tch_fr_encode(BUFPOS(bursts_p, 0), dummy, 
sizeof(dummy), 1);
chan_state->dl_facch_bursts = 8;
}
goto send_burst;
diff --git a/src/osmo-bts-trx/sched_lchan_tchh.c 
b/src/osmo-bts-trx/sched_lchan_tchh.c
index 23e59cf..77309cf 100644
--- a/src/osmo-bts-trx/sched_lchan_tchh.c
+++ b/src/osmo-bts-trx/sched_lchan_tchh.c
@@ -463,7 +463,7 @@
 * gaps in TCH/AHS.  See OS#6049.
 */
if (tch_mode == GSM48_CMODE_SPEECH_V1) {
-   rc = gsm0503_tch_hr_encode(bursts_p, NULL, 0);
+   rc = gsm0503_tch_hr_encode(BUFPOS(bursts_p, 0), NULL, 
0);
if (rc == 0)
goto send_burst;
}

diff --git a/src/osmo-bts-trx/sched_lchan_tchf.c 
b/src/osmo-bts-trx/sched_lchan_tchf.c
index 34af8a1..c0dfd47 100644
--- a/src/osmo-bts-trx/sched_lchan_tchf.c
+++ b/src/osmo-bts-trx/sched_lchan_tchf.c
@@ -490,6 +490,19 @@
}
 }

+struct msgb *tch_dummy_msgb(size_t size, uint8_t pad)
+{
+   struct msgb *msg;
+
+   msg = msgb_alloc(size, __func__);
+   OSMO_ASSERT(msg != NULL);
+
+   msg->l2h = msgb_put(msg, size);
+   memset(msg->l2h, pad, size);
+
+   return msg;
+}
+
 /* obtain a to-be-transmitted TCH/F (Full Traffic Channel) burst */
 int tx_tchf_fn(struct l1sched_ts *l1ts, struct trx_dl_burst_req *br)
 {
@@ -519,11 +532,6 @@
/* dequeue a TCH and/or a FACCH message to be transmitted */
tch_dl_dequeue(l1ts, br, _tch, _facch);
if (msg_tch == NULL && msg_facch == NULL) {
-   static const uint8_t dummy[GSM_MACBLOCK_LEN] = {
-   0x03, 0x03, 0x01, /* TODO: use randomized padding */
-   0x2b, 0x2b, 0x2b, 0x2b, 0x2b, 0x2b, 0x2b, 0x2b, 0x2b, 
0x2b,
-   0x2b, 0x2b, 0x2b, 0x2b, 0x2b, 0x2b, 0x2b, 0x2b, 0x2b, 
0x2b,
-   };
int rc;

LOGL1SB(DL1P, LOGL_DEBUG, l1ts, br, "No TCH or FACCH prim for 
transmit.\n");
@@ -541,13 +549,18 @@
case GSM48_CMODE_SPEECH_EFR:
rc = gsm0503_tch_fr_encode(BUFPOS(bursts_p, 0), NULL, 
0, 1);
if (rc == 0)
-   break;
+   goto send_burst;
/* fall-through */
+   case GSM48_CMODE_SIGN:
default:
-   gsm0503_tch_fr_encode(BUFPOS(bursts_p, 0), dummy, 
sizeof(dummy), 1);
-   chan_state->dl_facch_bursts = 8;
+   /* TODO: use randomized padding */
+   msg_facch = tch_dummy_msgb(GSM_MACBLOCK_LEN, 
GSM_MACBLOCK_PADDING);
+   /* dummy LAPDm func=UI frame */
+   msg_facch->l2h[0] = 0x03;
+   msg_facch->l2h[1] = 0x03;
+   msg_facch->l2h[2] = 0x01;
+   break;
}
-   goto send_burst;
}

/* Unlike SACCH, FACCH has no dedicated slots on the multiframe layout.
diff --git a/src/osmo-bts-trx/sched_lchan_tchh.c 
b/src/osmo-bts-trx/sched_lchan_tchh.c
index 77309cf..96ee5e8 100644
--- a/src/osmo-bts-trx/sched_lchan_tchh.c
+++ b/src/osmo-bts-trx/sched_lchan_tchh.c
@@ -399,6 +399,8 @@
 extern void tch_dl_dequeue(struct l1sched_ts *l1ts, const struct 
trx_dl_burst_req *br,
   struct msgb **msg_tch, struct msgb **msg_facch);

+struct msgb *tch_dummy_msgb(size_t size, uint8_t pad);
+
 /* obtain a to-be-transmitted TCH/H (Half Traffic Channel) burst */
 int tx_tchh_fn(struct l1sched_ts *l1ts, struct trx_dl_burst_req *br)
 {
@@ -445,11 +447,6 @@

/* no message at all, send a dummy L2 frame on FACCH */
if (msg_tch == NULL && msg_facch == NULL) {
-   static const uint8_t dummy[GSM_MACBLOCK_LEN] = {
-   0x03, 0x03, 0x01, /* TODO: use randomized padding */
-   0x2b, 0x2b, 0x2b, 0x2b, 0x2b, 0x2b, 0x2b, 0x2b, 0x2b, 
0x2b,
-   0x2b, 0x2b, 0x2b, 0x2b, 0x2b, 0x2b, 0x2b, 0x2b, 0x2b, 
0x2b,
-   };
int rc;

LOGL1SB(DL1P, LOGL_INFO, l1ts, br, "No TCH or FACCH prim for 
transmit.\n");
@@ -462,25 +459,30 @@
 * and decide what is the correct BTS Tx behavior for frame
 * gaps in TCH/AHS.  See OS#6049.
 */
-   if (tch_mode == GSM48_CMODE_SPEECH_V1) {
+   switch (tch_mode) {
+   case GSM48_CMODE_SPEECH_V1:
rc = gsm0503_tch_hr_encode(BUFPOS(bursts_p, 0), NULL, 

[M] Change in osmo-bts[master]: osmo-bts-trx: tx_tch[fh]_fn(): fix sending idle CSD frames

2023-11-14 Thread fixeria
fixeria has posted comments on this change. ( 
https://gerrit.osmocom.org/c/osmo-bts/+/34992?usp=email )

Change subject: osmo-bts-trx: tx_tch[fh]_fn(): fix sending idle CSD frames
..


Patch Set 1: Code-Review+2


--
To view, visit https://gerrit.osmocom.org/c/osmo-bts/+/34992?usp=email
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: osmo-bts
Gerrit-Branch: master
Gerrit-Change-Id: I0b25cfac41b6d8dcf3bfd9d46d51a9665f1b047a
Gerrit-Change-Number: 34992
Gerrit-PatchSet: 1
Gerrit-Owner: fixeria 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: falconia 
Gerrit-Reviewer: fixeria 
Gerrit-Reviewer: laforge 
Gerrit-Comment-Date: Tue, 14 Nov 2023 12:20:56 +
Gerrit-HasComments: No
Gerrit-Has-Labels: Yes
Gerrit-MessageType: comment


[S] Change in osmo-bts[master]: osmo-bts-trx: tx_tch[fh]_fn(): use BUFPOS macro everywhere

2023-11-14 Thread fixeria
fixeria has posted comments on this change. ( 
https://gerrit.osmocom.org/c/osmo-bts/+/34990?usp=email )

Change subject: osmo-bts-trx: tx_tch[fh]_fn(): use BUFPOS macro everywhere
..


Patch Set 1: Code-Review+2


--
To view, visit https://gerrit.osmocom.org/c/osmo-bts/+/34990?usp=email
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: osmo-bts
Gerrit-Branch: master
Gerrit-Change-Id: I16ce4c979c5b44fd67324eb2ed3da28a4b78221b
Gerrit-Change-Number: 34990
Gerrit-PatchSet: 1
Gerrit-Owner: fixeria 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: falconia 
Gerrit-Reviewer: fixeria 
Gerrit-Reviewer: laforge 
Gerrit-Comment-Date: Tue, 14 Nov 2023 12:20:49 +
Gerrit-HasComments: No
Gerrit-Has-Labels: Yes
Gerrit-MessageType: comment


[M] Change in osmo-bts[master]: osmo-bts-trx: tx_tch[fh]_fn(): rework generation of dummy FACCH

2023-11-14 Thread fixeria
fixeria has posted comments on this change. ( 
https://gerrit.osmocom.org/c/osmo-bts/+/34991?usp=email )

Change subject: osmo-bts-trx: tx_tch[fh]_fn(): rework generation of dummy FACCH
..


Patch Set 1: Code-Review+2


--
To view, visit https://gerrit.osmocom.org/c/osmo-bts/+/34991?usp=email
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: osmo-bts
Gerrit-Branch: master
Gerrit-Change-Id: I67cb5c6f4d15149996e17c78a59d66db396da8ff
Gerrit-Change-Number: 34991
Gerrit-PatchSet: 1
Gerrit-Owner: fixeria 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: falconia 
Gerrit-Reviewer: fixeria 
Gerrit-Reviewer: laforge 
Gerrit-Comment-Date: Tue, 14 Nov 2023 12:20:53 +
Gerrit-HasComments: No
Gerrit-Has-Labels: Yes
Gerrit-MessageType: comment


[S] Change in libosmocore[master]: coding: gsm0503_tch_a[fh]s_encode(): improve cmr/ft checks

2023-11-14 Thread fixeria
fixeria has submitted this change. ( 
https://gerrit.osmocom.org/c/libosmocore/+/34995?usp=email )

Change subject: coding: gsm0503_tch_a[fh]s_encode(): improve cmr/ft checks
..

coding: gsm0503_tch_a[fh]s_encode(): improve cmr/ft checks

Change-Id: If03d5b015ab1c8db56a4c67bdc8e36e260c06562
---
M src/coding/gsm0503_coding.c
1 file changed, 19 insertions(+), 26 deletions(-)

Approvals:
  laforge: Looks good to me, but someone else must approve
  Jenkins Builder: Verified
  osmith: Looks good to me, approved




diff --git a/src/coding/gsm0503_coding.c b/src/coding/gsm0503_coding.c
index 0e7f689..f8840c9 100644
--- a/src/coding/gsm0503_coding.c
+++ b/src/coding/gsm0503_coding.c
@@ -2465,19 +2465,11 @@

h = 0;

-   if (codec_mode_req) {
-   if (cmr >= codecs) {
-   /* FIXME: CMR ID is not in codec list! */
-   return -1;
-   }
-   id = cmr;
-   } else {
-   if (ft >= codecs) {
-   /* FIXME: FT ID is not in codec list! */
-   return -1;
-   }
-   id = ft;
-   }
+   id = codec_mode_req ? cmr : ft;
+   if (OSMO_UNLIKELY(id >= ARRAY_SIZE(gsm0503_afs_ic_ubit)))
+   return -1;
+   if (OSMO_UNLIKELY(ft >= codecs))
+   return -1;

switch (codec[ft]) {
case 7: /* TCH/AFS12.2 */
@@ -2970,19 +2962,11 @@

h = 0;

-   if (codec_mode_req) {
-   if (cmr >= codecs) {
-   /* FIXME: CMR ID %d not in codec list */
-   return -1;
-   }
-   id = cmr;
-   } else {
-   if (ft >= codecs) {
-   /* FIXME: FT ID %d not in codec list */
-   return -1;
-   }
-   id = ft;
-   }
+   id = codec_mode_req ? cmr : ft;
+   if (OSMO_UNLIKELY(id >= ARRAY_SIZE(gsm0503_ahs_ic_ubit)))
+   return -1;
+   if (OSMO_UNLIKELY(ft >= codecs))
+   return -1;

switch (codec[ft]) {
case 5: /* TCH/AHS7.95 */

--
To view, visit https://gerrit.osmocom.org/c/libosmocore/+/34995?usp=email
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: libosmocore
Gerrit-Branch: master
Gerrit-Change-Id: If03d5b015ab1c8db56a4c67bdc8e36e260c06562
Gerrit-Change-Number: 34995
Gerrit-PatchSet: 2
Gerrit-Owner: fixeria 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: fixeria 
Gerrit-Reviewer: laforge 
Gerrit-Reviewer: osmith 
Gerrit-MessageType: merged


[S] Change in libosmocore[master]: coding: gsm0503_tch_a[fh]s_encode(): make *codec const

2023-11-14 Thread fixeria
fixeria has submitted this change. ( 
https://gerrit.osmocom.org/c/libosmocore/+/34996?usp=email )

Change subject: coding: gsm0503_tch_a[fh]s_encode(): make *codec const
..

coding: gsm0503_tch_a[fh]s_encode(): make *codec const

Change-Id: I9e37a47c080cf57005e0205aa0d3cd25755a75f0
---
M include/osmocom/coding/gsm0503_coding.h
M src/coding/gsm0503_coding.c
2 files changed, 13 insertions(+), 4 deletions(-)

Approvals:
  Jenkins Builder: Verified
  laforge: Looks good to me, but someone else must approve
  osmith: Looks good to me, approved




diff --git a/include/osmocom/coding/gsm0503_coding.h 
b/include/osmocom/coding/gsm0503_coding.h
index 13d5344..3c51127 100644
--- a/include/osmocom/coding/gsm0503_coding.h
+++ b/include/osmocom/coding/gsm0503_coding.h
@@ -56,7 +56,7 @@
int *n_errors, int *n_bits_total);

 int gsm0503_tch_afs_encode(ubit_t *bursts, const uint8_t *tch_data, int len,
-   int codec_mode_req, uint8_t *codec, int codecs, uint8_t ft,
+   int codec_mode_req, const uint8_t *codec, int codecs, uint8_t ft,
uint8_t cmr);
 int gsm0503_tch_afs_decode(uint8_t *tch_data, const sbit_t *bursts,
int codec_mode_req, uint8_t *codec, int codecs, uint8_t *ft,
@@ -66,7 +66,7 @@
uint8_t *cmr, int *n_errors, int *n_bits_total, uint8_t *dtx);

 int gsm0503_tch_ahs_encode(ubit_t *bursts, const uint8_t *tch_data, int len,
-   int codec_mode_req, uint8_t *codec, int codecs, uint8_t ft, uint8_t 
cmr);
+   int codec_mode_req, const uint8_t *codec, int codecs, uint8_t ft, 
uint8_t cmr);
 int gsm0503_tch_ahs_decode(uint8_t *tch_data, const sbit_t *bursts, int odd,
int codec_mode_req, uint8_t *codec, int codecs, uint8_t *ft,
uint8_t *cmr, int *n_errors, int *n_bits_total);
diff --git a/src/coding/gsm0503_coding.c b/src/coding/gsm0503_coding.c
index f8840c9..8effef5 100644
--- a/src/coding/gsm0503_coding.c
+++ b/src/coding/gsm0503_coding.c
@@ -2447,7 +2447,7 @@
  *  \param[in] cmr Codec Mode Request (used in codec_mode_req = 1 only)
  *  \returns 0 in case of success; negative on error */
 int gsm0503_tch_afs_encode(ubit_t *bursts, const uint8_t *tch_data, int len,
-   int codec_mode_req, uint8_t *codec, int codecs, uint8_t ft,
+   int codec_mode_req, const uint8_t *codec, int codecs, uint8_t ft,
uint8_t cmr)
 {
ubit_t iB[912], cB[456], h;
@@ -2935,7 +2935,7 @@
  *  \param[in] cmr Codec Mode Request (used in codec_mode_req = 1 only)
  *  \returns 0 in case of success; negative on error */
 int gsm0503_tch_ahs_encode(ubit_t *bursts, const uint8_t *tch_data, int len,
-   int codec_mode_req, uint8_t *codec, int codecs, uint8_t ft,
+   int codec_mode_req, const uint8_t *codec, int codecs, uint8_t ft,
uint8_t cmr)
 {
ubit_t iB[912], cB[456], h;

--
To view, visit https://gerrit.osmocom.org/c/libosmocore/+/34996?usp=email
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: libosmocore
Gerrit-Branch: master
Gerrit-Change-Id: I9e37a47c080cf57005e0205aa0d3cd25755a75f0
Gerrit-Change-Number: 34996
Gerrit-PatchSet: 2
Gerrit-Owner: fixeria 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: fixeria 
Gerrit-Reviewer: laforge 
Gerrit-Reviewer: osmith 
Gerrit-MessageType: merged


[S] Change in osmo-ttcn3-hacks[master]: hnbgw: run TC_second_rab_assignment on nightly

2023-11-14 Thread osmith
Hello Jenkins Builder,

I'd like you to reexamine a change. Please visit

https://gerrit.osmocom.org/c/osmo-ttcn3-hacks/+/35012?usp=email

to look at the new patch set (#2).


Change subject: hnbgw: run TC_second_rab_assignment on nightly
..

hnbgw: run TC_second_rab_assignment on nightly

Fixes: OS#6253
Change-Id: Id09b1a22dbd391c19ecfe34af990ec1ef3bb5089
---
M hnbgw/HNBGW_Tests.ttcn
1 file changed, 14 insertions(+), 1 deletion(-)


  git pull ssh://gerrit.osmocom.org:29418/osmo-ttcn3-hacks 
refs/changes/12/35012/2
--
To view, visit https://gerrit.osmocom.org/c/osmo-ttcn3-hacks/+/35012?usp=email
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: osmo-ttcn3-hacks
Gerrit-Branch: master
Gerrit-Change-Id: Id09b1a22dbd391c19ecfe34af990ec1ef3bb5089
Gerrit-Change-Number: 35012
Gerrit-PatchSet: 2
Gerrit-Owner: osmith 
Gerrit-Reviewer: Jenkins Builder
Gerrit-MessageType: newpatchset


[S] Change in osmo-ttcn3-hacks[master]: hnbgw: run TC_second_rab_assignment on nightly

2023-11-14 Thread osmith
osmith has uploaded this change for review. ( 
https://gerrit.osmocom.org/c/osmo-ttcn3-hacks/+/35012?usp=email )


Change subject: hnbgw: run TC_second_rab_assignment on nightly
..

hnbgw: run TC_second_rab_assignment on nightly

Related: OS#6253
Change-Id: Id09b1a22dbd391c19ecfe34af990ec1ef3bb5089
---
M hnbgw/HNBGW_Tests.ttcn
1 file changed, 14 insertions(+), 1 deletion(-)



  git pull ssh://gerrit.osmocom.org:29418/osmo-ttcn3-hacks 
refs/changes/12/35012/1

diff --git a/hnbgw/HNBGW_Tests.ttcn b/hnbgw/HNBGW_Tests.ttcn
index adb32bd..5bcd40c 100644
--- a/hnbgw/HNBGW_Tests.ttcn
+++ b/hnbgw/HNBGW_Tests.ttcn
@@ -2710,7 +2710,10 @@
execute( TC_sgsnpool_sccp_n_pcstate_detaches_cnlink() );
execute( TC_sgsnpool_sccp_n_pcstate_attaches_cnlink() );

-   execute(TC_second_rab_assignment());
+   /* Run only on nightly since it makes osmo-hnbgw <= 1.5.0 crash: 
OS#6253 */
+   if (f_osmo_repo_is("nightly")) {
+   execute(TC_second_rab_assignment());
+   }

/* Run at the end since it makes osmo-hnbgw <= 1.3.0 crash: OS#5676 */
execute(TC_hnb_reregister_reuse_sctp_assoc());

--
To view, visit https://gerrit.osmocom.org/c/osmo-ttcn3-hacks/+/35012?usp=email
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: osmo-ttcn3-hacks
Gerrit-Branch: master
Gerrit-Change-Id: Id09b1a22dbd391c19ecfe34af990ec1ef3bb5089
Gerrit-Change-Number: 35012
Gerrit-PatchSet: 1
Gerrit-Owner: osmith 
Gerrit-MessageType: newchange


[S] Change in libosmocore[master]: coding: gsm0503_tch_a[fh]s_encode(): make *codec const

2023-11-14 Thread osmith
Attention is currently required from: fixeria, laforge.

osmith has posted comments on this change. ( 
https://gerrit.osmocom.org/c/libosmocore/+/34996?usp=email )

Change subject: coding: gsm0503_tch_a[fh]s_encode(): make *codec const
..


Patch Set 1: Code-Review+2


--
To view, visit https://gerrit.osmocom.org/c/libosmocore/+/34996?usp=email
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: libosmocore
Gerrit-Branch: master
Gerrit-Change-Id: I9e37a47c080cf57005e0205aa0d3cd25755a75f0
Gerrit-Change-Number: 34996
Gerrit-PatchSet: 1
Gerrit-Owner: fixeria 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: laforge 
Gerrit-Reviewer: osmith 
Gerrit-Attention: laforge 
Gerrit-Attention: fixeria 
Gerrit-Comment-Date: Tue, 14 Nov 2023 10:23:43 +
Gerrit-HasComments: No
Gerrit-Has-Labels: Yes
Gerrit-MessageType: comment


[S] Change in libosmocore[master]: coding: gsm0503_tch_a[fh]s_encode(): improve cmr/ft checks

2023-11-14 Thread osmith
Attention is currently required from: fixeria.

osmith has posted comments on this change. ( 
https://gerrit.osmocom.org/c/libosmocore/+/34995?usp=email )

Change subject: coding: gsm0503_tch_a[fh]s_encode(): improve cmr/ft checks
..


Patch Set 1: Code-Review+2


--
To view, visit https://gerrit.osmocom.org/c/libosmocore/+/34995?usp=email
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: libosmocore
Gerrit-Branch: master
Gerrit-Change-Id: If03d5b015ab1c8db56a4c67bdc8e36e260c06562
Gerrit-Change-Number: 34995
Gerrit-PatchSet: 1
Gerrit-Owner: fixeria 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: laforge 
Gerrit-Reviewer: osmith 
Gerrit-Attention: fixeria 
Gerrit-Comment-Date: Tue, 14 Nov 2023 10:23:28 +
Gerrit-HasComments: No
Gerrit-Has-Labels: Yes
Gerrit-MessageType: comment


[S] Change in osmo-ci[master]: tarballs: add osmo_dia2gsup

2023-11-14 Thread osmith
osmith has submitted this change. ( 
https://gerrit.osmocom.org/c/osmo-ci/+/34976?usp=email )

Change subject: tarballs: add osmo_dia2gsup
..

tarballs: add osmo_dia2gsup

Change-Id: I9cbd3d3ce27a4b4c9c8e19b2876386d170d4f0a6
---
M scripts/common.sh
M scripts/tarballs/publish-tarballs-for-tags.sh
2 files changed, 23 insertions(+), 0 deletions(-)

Approvals:
  osmith: Looks good to me, approved
  Jenkins Builder: Verified
  fixeria: Looks good to me, but someone else must approve




diff --git a/scripts/common.sh b/scripts/common.sh
index ea106e2..1081859 100644
--- a/scripts/common.sh
+++ b/scripts/common.sh
@@ -142,6 +142,9 @@
osmo-isdntap)
echo "$OSMO_GIT_URL_GITEA"/retronetworking/"$1"
;;
+   osmo_dia2gsup)
+   echo "$OSMO_GIT_URL_GERRIT"/erlang/"$1"
+   ;;
*)
echo "$OSMO_GIT_URL_GERRIT"/"$1"
;;
diff --git a/scripts/tarballs/publish-tarballs-for-tags.sh 
b/scripts/tarballs/publish-tarballs-for-tags.sh
index c185c21..4ef3b5f 100755
--- a/scripts/tarballs/publish-tarballs-for-tags.sh
+++ b/scripts/tarballs/publish-tarballs-for-tags.sh
@@ -42,6 +42,7 @@
osmo-sysmon
osmo-trx
osmo-uecups
+   osmo_dia2gsup
osmocom-bb
rtl-sdr
simtrace2
@@ -240,6 +241,11 @@

cd /src/$project_path

+   # Erlang projects: download build depends
+   if [ -e contrib/generate_build_dep.sh ]; then
+   su build -c \"HOME=/build 
contrib/generate_build_dep.sh\"
+   fi
+
if /tarballs/prefer-configure.sh \"$repo\" \"$tag\"; 
then
su build -c \"autoreconf -fi\"
case \"$repo\" in
@@ -255,6 +261,11 @@
else
su build -c \"git archive -o $tarball_name 
$tag\"
fi
+
+   # Erlang projects: add build depends to release tarball
+   if [ -e build_dep.tar.gz ]; then
+   su build -c \"tar -rf $tarball_name 
build_dep.tar.gz\"
+   fi
"; then
echo "$LOG_PREFIX Building tarball failed!"
exit 1

--
To view, visit https://gerrit.osmocom.org/c/osmo-ci/+/34976?usp=email
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: osmo-ci
Gerrit-Branch: master
Gerrit-Change-Id: I9cbd3d3ce27a4b4c9c8e19b2876386d170d4f0a6
Gerrit-Change-Number: 34976
Gerrit-PatchSet: 1
Gerrit-Owner: osmith 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: daniel 
Gerrit-Reviewer: dexter 
Gerrit-Reviewer: fixeria 
Gerrit-Reviewer: laforge 
Gerrit-Reviewer: osmith 
Gerrit-MessageType: merged


[S] Change in osmo-ci[master]: tarballs: git archive: make proper tar.bz2

2023-11-14 Thread osmith
osmith has submitted this change. ( 
https://gerrit.osmocom.org/c/osmo-ci/+/34978?usp=email )

Change subject: tarballs: git archive: make proper tar.bz2
..

tarballs: git archive: make proper tar.bz2

Compress the tarball from "git archive" with bzip2 to turn it into a
proper .tar.bz2. Previously the archive was named .tar.bz2, but it was
just a regular tarball as git archive didn't guess the type from the
filename (supposedly this works for .tar.gz and some others) and just
defaulted to tar.

Move the code that adds build_dep.tar.gz to the archive before the bzip2
call, because tar can't add files to the archive if it is compressed.

Change-Id: I5830f9123150540a6467c19c64461d2fa1972a52
---
M scripts/tarballs/publish-tarballs-for-tags.sh
1 file changed, 27 insertions(+), 7 deletions(-)

Approvals:
  Jenkins Builder: Verified
  fixeria: Looks good to me, but someone else must approve
  daniel: Looks good to me, but someone else must approve
  osmith: Looks good to me, approved




diff --git a/scripts/tarballs/publish-tarballs-for-tags.sh 
b/scripts/tarballs/publish-tarballs-for-tags.sh
index 05d9f30..46a2e17 100755
--- a/scripts/tarballs/publish-tarballs-for-tags.sh
+++ b/scripts/tarballs/publish-tarballs-for-tags.sh
@@ -260,14 +260,16 @@
esac
su build -c \"make dist-bzip2\"
else
-   su build -c \"git archive --prefix=$prefix/ -o 
$tarball_name $tag\"
-   fi
+   su build -c \"git archive --prefix=$prefix/ -o 
$prefix.tar $tag\"

-   # Erlang projects: add build depends to release tarball
-   if [ -e build_dep.tar.gz ]; then
-   su build -c \"mkdir $prefix\"
-   su build -c \"mv build_dep.tar.gz $prefix\"
-   su build -c \"tar -rf $tarball_name 
$prefix/build_dep.tar.gz\"
+   # Erlang projects: add build depends to release 
tarball
+   if [ -e build_dep.tar.gz ]; then
+   su build -c \"mkdir $prefix\"
+   su build -c \"mv build_dep.tar.gz 
$prefix\"
+   su build -c \"tar -rf $prefix.tar 
$prefix/build_dep.tar.gz\"
+   fi
+
+   su build -c \"bzip2 -9 $prefix.tar\"
fi
"; then
echo "$LOG_PREFIX Building tarball failed!"

--
To view, visit https://gerrit.osmocom.org/c/osmo-ci/+/34978?usp=email
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: osmo-ci
Gerrit-Branch: master
Gerrit-Change-Id: I5830f9123150540a6467c19c64461d2fa1972a52
Gerrit-Change-Number: 34978
Gerrit-PatchSet: 1
Gerrit-Owner: osmith 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: daniel 
Gerrit-Reviewer: fixeria 
Gerrit-Reviewer: osmith 
Gerrit-MessageType: merged


[S] Change in osmo-ci[master]: tarballs: git archive: put files in directory

2023-11-14 Thread osmith
osmith has submitted this change. ( 
https://gerrit.osmocom.org/c/osmo-ci/+/34977?usp=email )

Change subject: tarballs: git archive: put files in directory
..

tarballs: git archive: put files in directory

Make the releases created from the "git archive" code path more similar
to the autotools releases, by having all files in a subdirectory with
the project name and tag name instead of having them directly in the
root of the tarball.

  $ tree osmo_dia2gsup-0.1.1 | head
  osmo_dia2gsup-0.1.1
  ├── build_dep.tar.gz
  ├── contrib
  │   ├── generate_build_dep.sh
  │   ├── jenkins.sh
  │   └── systemd
  │   └── osmo_dia2gsup.service
  ├── debian
  │   ├── changelog
  │   ├── compat

Change-Id: If37dcdc04278de0d4479cf72e0ca33c90b7deea8
---
M scripts/tarballs/publish-tarballs-for-tags.sh
1 file changed, 31 insertions(+), 2 deletions(-)

Approvals:
  daniel: Looks good to me, but someone else must approve
  osmith: Looks good to me, approved
  Jenkins Builder: Verified
  fixeria: Looks good to me, but someone else must approve




diff --git a/scripts/tarballs/publish-tarballs-for-tags.sh 
b/scripts/tarballs/publish-tarballs-for-tags.sh
index 4ef3b5f..05d9f30 100755
--- a/scripts/tarballs/publish-tarballs-for-tags.sh
+++ b/scripts/tarballs/publish-tarballs-for-tags.sh
@@ -220,6 +220,7 @@
local project_path="$2"
local tag="$3"
local tarball_name="$(get_tarball_name "$project_path" "$tag")"
+   local prefix="$(echo "$tarball_name" | sed s/\.tar\.bz2//)"
local uid_user="$(id -u)"
echo "$LOG_PREFIX Building release tarball: $tarball_name"

@@ -259,12 +260,14 @@
esac
su build -c \"make dist-bzip2\"
else
-   su build -c \"git archive -o $tarball_name 
$tag\"
+   su build -c \"git archive --prefix=$prefix/ -o 
$tarball_name $tag\"
fi

# Erlang projects: add build depends to release tarball
if [ -e build_dep.tar.gz ]; then
-   su build -c \"tar -rf $tarball_name 
build_dep.tar.gz\"
+   su build -c \"mkdir $prefix\"
+   su build -c \"mv build_dep.tar.gz $prefix\"
+   su build -c \"tar -rf $tarball_name 
$prefix/build_dep.tar.gz\"
fi
"; then
echo "$LOG_PREFIX Building tarball failed!"

--
To view, visit https://gerrit.osmocom.org/c/osmo-bts/+/34990?usp=email
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: osmo-bts
Gerrit-Branch: master
Gerrit-Change-Id: I16ce4c979c5b44fd67324eb2ed3da28a4b78221b
Gerrit-Change-Number: 34990
Gerrit-PatchSet: 1
Gerrit-Owner: fixeria 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: falconia 
Gerrit-Reviewer: fixeria 
Gerrit-Reviewer: laforge 
Gerrit-MessageType: merged


[M] Change in osmo-bts[master]: osmo-bts-trx: tx_tch[fh]_fn(): fix sending idle CSD frames

2023-11-14 Thread fixeria
fixeria has submitted this change. ( 
https://gerrit.osmocom.org/c/osmo-bts/+/34992?usp=email )

Change subject: osmo-bts-trx: tx_tch[fh]_fn(): fix sending idle CSD frames
..

osmo-bts-trx: tx_tch[fh]_fn(): fix sending idle CSD frames

In accordance with 3GPP TS 44.021, sections 8.1.6 and 10.2.3, the
transmission of idle frames to the DTE is mandated when no data is
received from the radio interface.  An idle frame has all data,
status, and E-bits to binary '1' (excluding the alignment pattern).
This requirement is currently implemented for the Uplink, see
function csd_v110_rtp_encode().

However, 3GPP TS 44.021 does not explicitly specify whether the same
rule is applicable to the Downlink, perhaps assuming a continuous
stream of bits on the CSD-over-TDM link.  Currently, we transmit
a sequence of binary '0' on the Downlink instead of idle frames.

* In non-transparent (RLP) mode, whether all bits in a block are
  set to binary '0' or '1' has no impact, as both scenarios lead
  to an incorrect FCS.
* In transparent sync mode, any filling be it binary '0' or '1'
  is perceived as incorrect or unexpected.
* In transparent async mode, it is more logical to transmit a
  sequence of binary '1,' which will be interpreted as
  a sequence of stop bits.

Let's align the Downlink with the Uplink for consistency and transmit
idle frames when no data is available for transmission.  The modified
60-bit V.110 frames exclude the alignment pattern, so sending a
sequence of binary '1' is enough to achieve the intended goal.

Change-Id: I0b25cfac41b6d8dcf3bfd9d46d51a9665f1b047a
Related: OS#1572
---
M src/osmo-bts-trx/sched_lchan_tchf.c
M src/osmo-bts-trx/sched_lchan_tchh.c
2 files changed, 80 insertions(+), 20 deletions(-)

Approvals:
  Jenkins Builder: Verified
  fixeria: Looks good to me, approved
  laforge: Looks good to me, but someone else must approve
  falconia: Looks good to me, but someone else must approve




diff --git a/src/osmo-bts-trx/sched_lchan_tchf.c 
b/src/osmo-bts-trx/sched_lchan_tchf.c
index c0dfd47..0138a2a 100644
--- a/src/osmo-bts-trx/sched_lchan_tchf.c
+++ b/src/osmo-bts-trx/sched_lchan_tchf.c
@@ -535,16 +535,25 @@
int rc;

LOGL1SB(DL1P, LOGL_DEBUG, l1ts, br, "No TCH or FACCH prim for 
transmit.\n");
    /* If the channel mode is TCH/FS or TCH/EFS, transmit a dummy
 * speech block with inverted CRC3, designed to induce a BFI
 * condition in the MS receiver.  In all other channel modes,
 * transmit dummy FACCH like we always did before.
 *
 * FIXME: someone who knows AMR needs to look at this problem
 * and decide what is the correct BTS Tx behavior for frame
 * gaps in TCH/AFS.  See OS#6049.
 */
switch (tch_mode) {
+   case GSM48_CMODE_DATA_12k0:
+   case GSM48_CMODE_DATA_6k0:
+   case GSM48_CMODE_DATA_3k6:
+   case GSM48_CMODE_DATA_14k5:
+   break; /* see below */
case GSM48_CMODE_SPEECH_V1:
case GSM48_CMODE_SPEECH_EFR:
rc = gsm0503_tch_fr_encode(BUFPOS(bursts_p, 0), NULL, 
0, 1);
@@ -591,30 +600,36 @@
break;
/* CSD (TCH/F9.6): 12.0 kbit/s radio interface rate */
case GSM48_CMODE_DATA_12k0:
-   if (msg_tch != NULL)
-   gsm0503_tch_fr96_encode(BUFPOS(bursts_p, 0), 
msgb_l2(msg_tch));
+   if (msg_tch == NULL)
+   msg_tch = tch_dummy_msgb(4 * 60, 0x01);
+   gsm0503_tch_fr96_encode(BUFPOS(bursts_p, 0), msgb_l2(msg_tch));
if (msg_facch != NULL)
gsm0503_tch_fr_facch_encode(BUFPOS(bursts_p, 0), 
msgb_l2(msg_facch));
break;
/* CSD (TCH/F4.8): 6.0 kbit/s radio interface rate */
case GSM48_CMODE_DATA_6k0:
-   if (msg_tch != NULL)
-   gsm0503_tch_fr48_encode(BUFPOS(bursts_p, 0), 
msgb_l2(msg_tch));
+   if (msg_tch == NULL)
+   msg_tch = tch_dummy_msgb(2 * 60, 0x01);
+   gsm0503_tch_fr48_encode(BUFPOS(bursts_p, 0), msgb_l2(msg_tch));
if (msg_facch != NULL)

[M] Change in osmo-bts[master]: osmo-bts-trx: tx_tch[fh]_fn(): rework generation of dummy FACCH

2023-11-14 Thread fixeria
fixeria has submitted this change. ( 
https://gerrit.osmocom.org/c/osmo-bts/+/34991?usp=email )

Change subject: osmo-bts-trx: tx_tch[fh]_fn(): rework generation of dummy FACCH
..

osmo-bts-trx: tx_tch[fh]_fn(): rework generation of dummy FACCH

Even though it might have a somewhat higher performance impact,
opting for the common code path for FACCH by allocating a msgb
on heap is more favorable for both readability and maintainability.

This choice is preferred over directly calling
gsm0503_tch_fr_encode() and then using a 'goto' statement.
A similar strategy will be adopted in an follow up patch for CSD.

Change-Id: I67cb5c6f4d15149996e17c78a59d66db396da8ff
Related: OS#1572
---
@@ -535,16 +535,25 @@
LOGL1SB(DL1P, LOGL_DEBUG, l1ts, br, "No TCH or FACCH prim for 
transmit.\n");
-   /* If the channel mode is TCH/FS or TCH/EFS, transmit a dummy
-* speech block with inverted CRC3, designed to induce a BFI
-* condition in the MS receiver.  In all other channel modes,
-* transmit dummy FACCH like we always did before.
+   /* - If the channel mode is TCH/FS or TCH/EFS, transmit a dummy
+*   speech block with inverted CRC3, designed to induce a BFI
+*   condition in the MS receiver.
+* - If the channel mode is one of the CSD modes, transmit an
+*   idle frame as described in 3GPP TS 44.021, sections 8.1.6
+*   and 10.2.3 (all data, status and E-bits set to binary '1').
+* - In all other channel modes, transmit dummy FACCH
+*   like we always did before.
 *
 * FIXME: someone who knows AMR needs to look at this problem
M src/osmo-bts-trx/sched_lchan_tchf.c
M src/osmo-bts-trx/sched_lchan_tchh.c
2 files changed, 61 insertions(+), 28 deletions(-)

Approvals:
  Jenkins Builder: Verified
  laforge: Looks good to me, but someone else must approve
  fixeria: Looks good to me, approved
  falconia: Looks good to me, but someone else must approve




--
To view, visit https://gerrit.osmocom.org/c/osmo-ci/+/34977?usp=email
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: osmo-ci
Gerrit-Branch: master
Gerrit-Change-Id: If37dcdc04278de0d4479cf72e0ca33c90b7deea8
Gerrit-Change-Number: 34977
Gerrit-PatchSet: 1
Gerrit-Owner: osmith 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: daniel 
Gerrit-Reviewer: fixeria 
Gerrit-Reviewer: osmith 
Gerrit-MessageType: merged


[S] Change in osmo-ci[master]: tarballs: git archive: make proper tar.bz2

2023-11-14 Thread osmith
osmith has posted comments on this change. ( 
https://gerrit.osmocom.org/c/osmo-ci/+/34978?usp=email )

Change subject: tarballs: git archive: make proper tar.bz2
..


Patch Set 1: Code-Review+2


--
To view, visit https://gerrit.osmocom.org/c/osmo-ci/+/34978?usp=email
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: osmo-ci
Gerrit-Branch: master
Gerrit-Change-Id: I5830f9123150540a6467c19c64461d2fa1972a52
Gerrit-Change-Number: 34978
Gerrit-PatchSet: 1
Gerrit-Owner: osmith 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: daniel 
Gerrit-Reviewer: fixeria 
Gerrit-Reviewer: osmith 
Gerrit-Comment-Date: Tue, 14 Nov 2023 10:09:48 +
Gerrit-HasComments: No
Gerrit-Has-Labels: Yes
Gerrit-MessageType: comment


[S] Change in osmo-ci[master]: tarballs: git archive: put files in directory

2023-11-14 Thread osmith
osmith has posted comments on this change. ( 
https://gerrit.osmocom.org/c/osmo-ci/+/34977?usp=email )

Change subject: tarballs: git archive: put files in directory
..


Patch Set 1: Code-Review+2


--
To view, visit https://gerrit.osmocom.org/c/osmo-ci/+/34977?usp=email
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: osmo-ci
Gerrit-Branch: master
Gerrit-Change-Id: If37dcdc04278de0d4479cf72e0ca33c90b7deea8
Gerrit-Change-Number: 34977
Gerrit-PatchSet: 1
Gerrit-Owner: osmith 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: daniel 
Gerrit-Reviewer: fixeria 
Gerrit-Reviewer: osmith 
Gerrit-Comment-Date: Tue, 14 Nov 2023 10:09:45 +
Gerrit-HasComments: No
Gerrit-Has-Labels: Yes
Gerrit-MessageType: comment


[S] Change in osmo-ci[master]: tarballs: add osmo_dia2gsup

2023-11-14 Thread osmith
Attention is currently required from: daniel, dexter, laforge.

osmith has posted comments on this change. ( 
https://gerrit.osmocom.org/c/osmo-ci/+/34976?usp=email )

Change subject: tarballs: add osmo_dia2gsup
..


Patch Set 1: Code-Review+2


--
To view, visit https://gerrit.osmocom.org/c/osmo-ci/+/34976?usp=email
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: osmo-ci
Gerrit-Branch: master
Gerrit-Change-Id: I9cbd3d3ce27a4b4c9c8e19b2876386d170d4f0a6
Gerrit-Change-Number: 34976
Gerrit-PatchSet: 1
Gerrit-Owner: osmith 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: daniel 
Gerrit-Reviewer: dexter 
Gerrit-Reviewer: fixeria 
Gerrit-Reviewer: laforge 
Gerrit-Reviewer: osmith 
Gerrit-Attention: laforge 
Gerrit-Attention: daniel 
Gerrit-Attention: dexter 
Gerrit-Comment-Date: Tue, 14 Nov 2023 10:09:41 +
Gerrit-HasComments: No
Gerrit-Has-Labels: Yes
Gerrit-MessageType: comment


[S] Change in osmo-bsc[master]: bsc: Make socket queue max. length configurable

2023-11-14 Thread daniel
Attention is currently required from: arehbein, dexter, laforge, pespin.

daniel has posted comments on this change. ( 
https://gerrit.osmocom.org/c/osmo-bsc/+/33892?usp=email )

Change subject: bsc: Make socket queue max. length configurable
..


Patch Set 8:

(2 comments)

File src/osmo-bsc/bsc_vty.c:

https://gerrit.osmocom.org/c/osmo-bsc/+/33892/comment/ef46c6d0_758599ad
PS8, Line 2499: size_t to = (net->pcu_sock_wqueue_len_max = 
atoi(argv[0]));
> this new variable is really not needed and just makes everything more 
> complex, specially with the pa […]
Ack


https://gerrit.osmocom.org/c/osmo-bsc/+/33892/comment/450acc4e_c0e41486
PS8, Line 2503: LOGP(DPCU, LOGL_INFO, "Have dropped %zu 
messages due to shortened max. message queue size (from: %zu to %zu)\n",
> it may be good to do vty_out with the same message here, to show the user of 
> the VTY what happened a […]
ACK



--
To view, visit https://gerrit.osmocom.org/c/osmo-bsc/+/33892?usp=email
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: osmo-bsc
Gerrit-Branch: master
Gerrit-Change-Id: Ic5f19f4613bccaf582997a4d02b689adee083a0b
Gerrit-Change-Number: 33892
Gerrit-PatchSet: 8
Gerrit-Owner: arehbein 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: dexter 
Gerrit-Reviewer: laforge 
Gerrit-Reviewer: pespin 
Gerrit-CC: daniel 
Gerrit-Attention: arehbein 
Gerrit-Attention: laforge 
Gerrit-Attention: pespin 
Gerrit-Attention: dexter 
Gerrit-Comment-Date: Tue, 14 Nov 2023 10:06:54 +
Gerrit-HasComments: Yes
Gerrit-Has-Labels: No
Comment-In-Reply-To: pespin 
Gerrit-MessageType: comment


[M] Change in libosmocore[master]: gsmtap_util: Simplify sink

2023-11-14 Thread daniel
Attention is currently required from: arehbein.

daniel has posted comments on this change. ( 
https://gerrit.osmocom.org/c/libosmocore/+/34881?usp=email )

Change subject: gsmtap_util: Simplify sink
..


Patch Set 4: Code-Review+1


--
To view, visit https://gerrit.osmocom.org/c/libosmocore/+/34881?usp=email
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: libosmocore
Gerrit-Branch: master
Gerrit-Change-Id: I4025920d5f62d17133e9b5fe81cd34a88c4f20b5
Gerrit-Change-Number: 34881
Gerrit-PatchSet: 4
Gerrit-Owner: arehbein 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: daniel 
Gerrit-Reviewer: laforge 
Gerrit-Attention: arehbein 
Gerrit-Comment-Date: Tue, 14 Nov 2023 10:03:22 +
Gerrit-HasComments: No
Gerrit-Has-Labels: Yes
Gerrit-MessageType: comment


[S] Change in osmo-bts[master]: osmo-bts-trx: add_sbits(): simplify, improve coding style

2023-11-14 Thread daniel
Attention is currently required from: fixeria.

daniel has posted comments on this change. ( 
https://gerrit.osmocom.org/c/osmo-bts/+/35009?usp=email )

Change subject: osmo-bts-trx: add_sbits(): simplify, improve coding style
..


Patch Set 1: Code-Review+1


--
To view, visit https://gerrit.osmocom.org/c/osmo-bts/+/35009?usp=email
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: osmo-bts
Gerrit-Branch: master
Gerrit-Change-Id: I518a8ea268a9a6d48b04c291a03e5efbed5f571d
Gerrit-Change-Number: 35009
Gerrit-PatchSet: 1
Gerrit-Owner: fixeria 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: daniel 
Gerrit-Reviewer: laforge 
Gerrit-Attention: fixeria 
Gerrit-Comment-Date: Tue, 14 Nov 2023 10:01:13 +
Gerrit-HasComments: No
Gerrit-Has-Labels: Yes
Gerrit-MessageType: comment


[S] Change in osmo-bts[master]: osmo-bts-trx: use BPLEN macro instead of magic numbers

2023-11-14 Thread daniel
Attention is currently required from: fixeria.

daniel has posted comments on this change. ( 
https://gerrit.osmocom.org/c/osmo-bts/+/35010?usp=email )

Change subject: osmo-bts-trx: use BPLEN macro instead of magic numbers
..


Patch Set 1: Code-Review+1


--
To view, visit https://gerrit.osmocom.org/c/osmo-bts/+/35010?usp=email
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: osmo-bts
Gerrit-Branch: master
Gerrit-Change-Id: I7d89b2e50c7eeb54b734c4959eeeb1c63a51a315
Gerrit-Change-Number: 35010
Gerrit-PatchSet: 1
Gerrit-Owner: fixeria 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: daniel 
Gerrit-Reviewer: laforge 
Gerrit-Attention: fixeria 
Gerrit-Comment-Date: Tue, 14 Nov 2023 10:01:04 +
Gerrit-HasComments: No
Gerrit-Has-Labels: Yes
Gerrit-MessageType: comment


[S] Change in ...osmo_dia2gsup[master]: osmo_dia2gsup: add config option diameter_connect_timer

2023-11-14 Thread daniel
Attention is currently required from: lynxis lazus.

daniel has posted comments on this change. ( 
https://gerrit.osmocom.org/c/erlang/osmo_dia2gsup/+/35002?usp=email )

Change subject: osmo_dia2gsup: add config option diameter_connect_timer
..


Patch Set 1: Code-Review+1


--
To view, visit 
https://gerrit.osmocom.org/c/erlang/osmo_dia2gsup/+/35002?usp=email
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: erlang/osmo_dia2gsup
Gerrit-Branch: master
Gerrit-Change-Id: I669a76022d866824e7b4e9f30dd7e51aa714ae7d
Gerrit-Change-Number: 35002
Gerrit-PatchSet: 1
Gerrit-Owner: lynxis lazus 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: daniel 
Gerrit-Reviewer: laforge 
Gerrit-Attention: lynxis lazus 
Gerrit-Comment-Date: Tue, 14 Nov 2023 10:00:27 +
Gerrit-HasComments: No
Gerrit-Has-Labels: Yes
Gerrit-MessageType: comment


[S] Change in osmo-ci[master]: tarballs: git archive: put files in directory

2023-11-14 Thread daniel
Attention is currently required from: osmith.

daniel has posted comments on this change. ( 
https://gerrit.osmocom.org/c/osmo-ci/+/34977?usp=email )

Change subject: tarballs: git archive: put files in directory
..


Patch Set 1: Code-Review+1


--
To view, visit https://gerrit.osmocom.org/c/osmo-ci/+/34977?usp=email
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: osmo-ci
Gerrit-Branch: master
Gerrit-Change-Id: If37dcdc04278de0d4479cf72e0ca33c90b7deea8
Gerrit-Change-Number: 34977
Gerrit-PatchSet: 1
Gerrit-Owner: osmith 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: daniel 
Gerrit-Reviewer: fixeria 
Gerrit-Attention: osmith 
Gerrit-Comment-Date: Tue, 14 Nov 2023 10:00:15 +
Gerrit-HasComments: No
Gerrit-Has-Labels: Yes
Gerrit-MessageType: comment


[S] Change in libosmocore[master]: core: add parity calculation functions for uint{32,16,8}_t

2023-11-14 Thread fixeria
Attention is currently required from: laforge, neels.

fixeria has posted comments on this change. ( 
https://gerrit.osmocom.org/c/libosmocore/+/35005?usp=email )

Change subject: core: add parity calculation functions for uint{32,16,8}_t
..


Patch Set 1:

(1 comment)

Commit Message:

https://gerrit.osmocom.org/c/libosmocore/+/35005/comment/9c1bc7ee_f8139623
PS1, Line 8:
> I guess it's for the softuart code that Vadim took over from my branch and 
> brings it mainline soon.
Yes, Harald's guess is correct. This was actually my initial plan, since I do 
need a parity checking logic for the soft-UART. But then I found a simpler 
solution and no longer need to use these functions, but I guess somebody might 
still find these functions useful?

P.S. I just discovered that both GCC and Clang offer `__builtin_parity`.



--
To view, visit https://gerrit.osmocom.org/c/libosmocore/+/35005?usp=email
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: libosmocore
Gerrit-Branch: master
Gerrit-Change-Id: I2d6265eac5ce062276a40f4968b129d8702c6117
Gerrit-Change-Number: 35005
Gerrit-PatchSet: 1
Gerrit-Owner: fixeria 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: laforge 
Gerrit-Reviewer: neels 
Gerrit-Attention: neels 
Gerrit-Attention: laforge 
Gerrit-Comment-Date: Tue, 14 Nov 2023 09:59:15 +
Gerrit-HasComments: Yes
Gerrit-Has-Labels: No
Comment-In-Reply-To: neels 
Comment-In-Reply-To: laforge 
Gerrit-MessageType: comment


[S] Change in osmo-ci[master]: tarballs: git archive: make proper tar.bz2

2023-11-14 Thread daniel
Attention is currently required from: osmith.

daniel has posted comments on this change. ( 
https://gerrit.osmocom.org/c/osmo-ci/+/34978?usp=email )

Change subject: tarballs: git archive: make proper tar.bz2
..


Patch Set 1: Code-Review+1


--
To view, visit https://gerrit.osmocom.org/c/osmo-ci/+/34978?usp=email
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: osmo-ci
Gerrit-Branch: master
Gerrit-Change-Id: I5830f9123150540a6467c19c64461d2fa1972a52
Gerrit-Change-Number: 34978
Gerrit-PatchSet: 1
Gerrit-Owner: osmith 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: daniel 
Gerrit-Reviewer: fixeria 
Gerrit-Attention: osmith 
Gerrit-Comment-Date: Tue, 14 Nov 2023 09:58:29 +
Gerrit-HasComments: No
Gerrit-Has-Labels: Yes
Gerrit-MessageType: comment


[S] Change in osmo-ttcn3-hacks[master]: hlr: add imsi unknown cause test case

2023-11-14 Thread daniel
Attention is currently required from: fixeria, laforge, lynxis lazus.

daniel has posted comments on this change. ( 
https://gerrit.osmocom.org/c/osmo-ttcn3-hacks/+/27569?usp=email )

Change subject: hlr: add imsi unknown cause test case
..


Patch Set 2: Code-Review+1


--
To view, visit https://gerrit.osmocom.org/c/osmo-ttcn3-hacks/+/27569?usp=email
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: osmo-ttcn3-hacks
Gerrit-Branch: master
Gerrit-Change-Id: I87c3a2d7304b81cfc11a364d933567e1a080b99a
Gerrit-Change-Number: 27569
Gerrit-PatchSet: 2
Gerrit-Owner: lynxis lazus 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: daniel 
Gerrit-Reviewer: fixeria 
Gerrit-Reviewer: neels 
Gerrit-CC: laforge 
Gerrit-Attention: laforge 
Gerrit-Attention: fixeria 
Gerrit-Attention: lynxis lazus 
Gerrit-Comment-Date: Tue, 14 Nov 2023 09:55:09 +
Gerrit-HasComments: No
Gerrit-Has-Labels: Yes
Gerrit-MessageType: comment


[S] Change in libosmocore[master]: coding: gsm0503_tch_a[fh]s_encode(): make *codec const

2023-11-14 Thread laforge
Attention is currently required from: fixeria, laforge, osmith.

laforge has posted comments on this change. ( 
https://gerrit.osmocom.org/c/libosmocore/+/34996?usp=email )

Change subject: coding: gsm0503_tch_a[fh]s_encode(): make *codec const
..


Patch Set 1: Code-Review+1


--
To view, visit https://gerrit.osmocom.org/c/libosmocore/+/34996?usp=email
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: libosmocore
Gerrit-Branch: master
Gerrit-Change-Id: I9e37a47c080cf57005e0205aa0d3cd25755a75f0
Gerrit-Change-Number: 34996
Gerrit-PatchSet: 1
Gerrit-Owner: fixeria 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: laforge 
Gerrit-Reviewer: osmith 
Gerrit-Attention: osmith 
Gerrit-Attention: laforge 
Gerrit-Attention: fixeria 
Gerrit-Comment-Date: Tue, 14 Nov 2023 09:53:55 +
Gerrit-HasComments: No
Gerrit-Has-Labels: Yes
Gerrit-MessageType: comment


[S] Change in libosmocore[master]: coding: gsm0503_tch_a[fh]s_encode(): improve cmr/ft checks

2023-11-14 Thread laforge
Attention is currently required from: fixeria.

laforge has posted comments on this change. ( 
https://gerrit.osmocom.org/c/libosmocore/+/34995?usp=email )

Change subject: coding: gsm0503_tch_a[fh]s_encode(): improve cmr/ft checks
..


Patch Set 1: Code-Review+1


--
To view, visit https://gerrit.osmocom.org/c/libosmocore/+/34995?usp=email
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: libosmocore
Gerrit-Branch: master
Gerrit-Change-Id: If03d5b015ab1c8db56a4c67bdc8e36e260c06562
Gerrit-Change-Number: 34995
Gerrit-PatchSet: 1
Gerrit-Owner: fixeria 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: laforge 
Gerrit-Attention: fixeria 
Gerrit-Comment-Date: Tue, 14 Nov 2023 09:41:25 +
Gerrit-HasComments: No
Gerrit-Has-Labels: Yes
Gerrit-MessageType: comment


[S] Change in osmo-bsc[master]: ASCI: Repeat notification after assigning MS to VGCS/VBS channel

2023-11-14 Thread fixeria
Attention is currently required from: jolly.

fixeria has posted comments on this change. ( 
https://gerrit.osmocom.org/c/osmo-bsc/+/35008?usp=email )

Change subject: ASCI: Repeat notification after assigning MS to VGCS/VBS channel
..


Patch Set 2: Code-Review+2


--
To view, visit https://gerrit.osmocom.org/c/osmo-bsc/+/35008?usp=email
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: osmo-bsc
Gerrit-Branch: master
Gerrit-Change-Id: Ife568b8c2756be332c0b8de2f66f6e537c4d
Gerrit-Change-Number: 35008
Gerrit-PatchSet: 2
Gerrit-Owner: jolly 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: fixeria 
Gerrit-Reviewer: laforge 
Gerrit-Attention: jolly 
Gerrit-Comment-Date: Tue, 14 Nov 2023 09:40:39 +
Gerrit-HasComments: No
Gerrit-Has-Labels: Yes
Gerrit-MessageType: comment


[S] Change in osmo-bts[master]: osmo-bts-trx: use BPLEN macro instead of magic numbers

2023-11-14 Thread laforge
Attention is currently required from: fixeria.

laforge has posted comments on this change. ( 
https://gerrit.osmocom.org/c/osmo-bts/+/35010?usp=email )

Change subject: osmo-bts-trx: use BPLEN macro instead of magic numbers
..


Patch Set 1: Code-Review+1


--
To view, visit https://gerrit.osmocom.org/c/osmo-bts/+/35010?usp=email
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: osmo-bts
Gerrit-Branch: master
Gerrit-Change-Id: I7d89b2e50c7eeb54b734c4959eeeb1c63a51a315
Gerrit-Change-Number: 35010
Gerrit-PatchSet: 1
Gerrit-Owner: fixeria 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: laforge 
Gerrit-Attention: fixeria 
Gerrit-Comment-Date: Tue, 14 Nov 2023 09:40:04 +
Gerrit-HasComments: No
Gerrit-Has-Labels: Yes
Gerrit-MessageType: comment


[S] Change in osmo-bts[master]: osmo-bts-trx: add_sbits(): simplify, improve coding style

2023-11-14 Thread laforge
Attention is currently required from: fixeria.

laforge has posted comments on this change. ( 
https://gerrit.osmocom.org/c/osmo-bts/+/35009?usp=email )

Change subject: osmo-bts-trx: add_sbits(): simplify, improve coding style
..


Patch Set 1: Code-Review+1


--
To view, visit https://gerrit.osmocom.org/c/osmo-bts/+/35009?usp=email
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: osmo-bts
Gerrit-Branch: master
Gerrit-Change-Id: I518a8ea268a9a6d48b04c291a03e5efbed5f571d
Gerrit-Change-Number: 35009
Gerrit-PatchSet: 1
Gerrit-Owner: fixeria 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: laforge 
Gerrit-Attention: fixeria 
Gerrit-Comment-Date: Tue, 14 Nov 2023 09:39:50 +
Gerrit-HasComments: No
Gerrit-Has-Labels: Yes
Gerrit-MessageType: comment


[S] Change in osmo-bts[master]: osmo-bts-trx: eliminate ul_bursts_prev, use the primary buffer

2023-11-14 Thread laforge
Attention is currently required from: dexter, fixeria.

laforge has posted comments on this change. ( 
https://gerrit.osmocom.org/c/osmo-bts/+/35011?usp=email )

Change subject: osmo-bts-trx: eliminate ul_bursts_prev, use the primary buffer
..


Patch Set 1: Code-Review+1


--
To view, visit https://gerrit.osmocom.org/c/osmo-bts/+/35011?usp=email
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: osmo-bts
Gerrit-Branch: master
Gerrit-Change-Id: I15047cd1df4476054b36f05616e41f5297d9bfe5
Gerrit-Change-Number: 35011
Gerrit-PatchSet: 1
Gerrit-Owner: fixeria 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: dexter 
Gerrit-Reviewer: laforge 
Gerrit-Attention: fixeria 
Gerrit-Attention: dexter 
Gerrit-Comment-Date: Tue, 14 Nov 2023 09:39:24 +
Gerrit-HasComments: No
Gerrit-Has-Labels: Yes
Gerrit-MessageType: comment


[S] Change in osmo-bsc[master]: ASCI: Repeat notification after assigning MS to VGCS/VBS channel

2023-11-14 Thread laforge
Attention is currently required from: fixeria, jolly.

laforge has posted comments on this change. ( 
https://gerrit.osmocom.org/c/osmo-bsc/+/35008?usp=email )

Change subject: ASCI: Repeat notification after assigning MS to VGCS/VBS channel
..


Patch Set 2: Code-Review+1


--
To view, visit https://gerrit.osmocom.org/c/osmo-bsc/+/35008?usp=email
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: osmo-bsc
Gerrit-Branch: master
Gerrit-Change-Id: Ife568b8c2756be332c0b8de2f66f6e537c4d
Gerrit-Change-Number: 35008
Gerrit-PatchSet: 2
Gerrit-Owner: jolly 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: fixeria 
Gerrit-Reviewer: laforge 
Gerrit-Attention: jolly 
Gerrit-Attention: fixeria 
Gerrit-Comment-Date: Tue, 14 Nov 2023 09:38:59 +
Gerrit-HasComments: No
Gerrit-Has-Labels: Yes
Gerrit-MessageType: comment


[M] Change in osmo-hnbgw[master]: allow (second) CS RAB Assignment Request without RTP info

2023-11-14 Thread laforge
laforge has posted comments on this change. ( 
https://gerrit.osmocom.org/c/osmo-hnbgw/+/34974?usp=email )

Change subject: allow (second) CS RAB Assignment Request without RTP info
..


Patch Set 4:

(1 comment)

Commit Message:

https://gerrit.osmocom.org/c/osmo-hnbgw/+/34974/comment/d186709b_57f2c6f5
PS4, Line 19: Do not (yet?) supp
> the "yet" is about modifying an active RAB -- IIUC for handover that wouldn't 
> be needed. […]
for intra-RNC: Yes I would assume that is the normal case, but we're making 
assumptions here (that the RNC will hide the internal RAN topology / IP 
addresses and present a fixed RTP endpoint towards the CN). Likely but not 
guaranteed.

As for inter-RNC: Likewise, there could in theory be some different support in 
terms of codecs/rates.  Again, likely that it's not required in a usual case, 
but I'd say there are potential cases and the specs allow for it, certainly.



--
To view, visit https://gerrit.osmocom.org/c/osmo-hnbgw/+/34974?usp=email
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: osmo-hnbgw
Gerrit-Branch: master
Gerrit-Change-Id: I25bf19981cd75a87a7ceb3382dae1ec626ae475c
Gerrit-Change-Number: 34974
Gerrit-PatchSet: 4
Gerrit-Owner: neels 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: laforge 
Gerrit-Reviewer: osmith 
Gerrit-Comment-Date: Tue, 14 Nov 2023 08:39:47 +
Gerrit-HasComments: Yes
Gerrit-Has-Labels: No
Comment-In-Reply-To: neels 
Comment-In-Reply-To: laforge 
Gerrit-MessageType: comment